# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fileinfo_list.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x66ileinfo_list.proto\x12\x11insta360.messages"/\n\x08\x46ileInfo\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\x0c"?\n\rFileInfo_List\x12.\n\tfile_info\x18\x01 \x03(\x0b\x32\x1b.insta360.messages.FileInfoB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "fileinfo_list_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_FILEINFO"]._serialized_start = 42
    _globals["_FILEINFO"]._serialized_end = 89
    _globals["_FILEINFO_LIST"]._serialized_start = 91
    _globals["_FILEINFO_LIST"]._serialized_end = 154
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: start_timelapse.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from timelapse_pb2 import *
from extra_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15start_timelapse.proto\x12\x11insta360.messages\x1a\x0ftimelapse.proto\x1a\x10\x65xtra_info.proto"z\n\x0eStartTimelapse\x12.\n\x04mode\x18\x01 \x01(\x0e\x32 .insta360.messages.TimelapseMode\x12\x38\n\x0e\x65xtra_metadata\x18\x02 \x01(\x0b\x32 .insta360.messages.ExtraMetadata"\x14\n\x12StartTimelapseRespB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "start_timelapse_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_STARTTIMELAPSE"]._serialized_start = 79
    _globals["_STARTTIMELAPSE"]._serialized_end = 201
    _globals["_STARTTIMELAPSERESP"]._serialized_start = 203
    _globals["_STARTTIMELAPSERESP"]._serialized_end = 223
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chargebox.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from battery_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0f\x63hargebox.proto\x12\x11insta360.messages\x1a\rbattery.proto"\xe9\x05\n\x18\x43hargeboxConnectedStatus\x12\x65\n\x19\x63hargebox_connected_state\x18\x01 \x01(\x0e\x32\x42.insta360.messages.ChargeboxConnectedStatus.ChargeboxConnectedType\x12\x44\n\x1a\x63hargingbox_battery_status\x18\x02 \x01(\x0b\x32 .insta360.messages.BatteryStatus\x12^\n\x16\x63hargebox_onoff_status\x18\x03 \x01(\x0e\x32>.insta360.messages.ChargeboxConnectedStatus.ChargeboxOnOffInfo\x12n\n\x1d\x63hargebox_usb_connected_state\x18\x04 \x01(\x0e\x32G.insta360.messages.ChargeboxConnectedStatus.ChargeboxUsbBtConnectedType\x12m\n\x1c\x63hargebox_bt_connected_state\x18\x05 \x01(\x0e\x32G.insta360.messages.ChargeboxConnectedStatus.ChargeboxUsbBtConnectedType"9\n\x16\x43hargeboxConnectedType\x12\x10\n\x0c\x64isconnected\x10\x00\x12\r\n\tconnected\x10\x01"-\n\x12\x43hargeboxOnOffInfo\x12\x0b\n\x07offline\x10\x00\x12\n\n\x06online\x10\x01"w\n\x1b\x43hargeboxUsbBtConnectedType\x12\x1b\n\x17usb_bt_status_undefined\x10\x00\x12\x1e\n\x1ausb_bt_status_disconnected\x10\x01\x12\x1b\n\x17usb_bt_status_connected\x10\x02\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chargebox_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CHARGEBOXCONNECTEDSTATUS"]._serialized_start = 54
    _globals["_CHARGEBOXCONNECTEDSTATUS"]._serialized_end = 799
    _globals["_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXCONNECTEDTYPE"]._serialized_start = 574
    _globals["_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXCONNECTEDTYPE"]._serialized_end = 631
    _globals["_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXONOFFINFO"]._serialized_start = 633
    _globals["_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXONOFFINFO"]._serialized_end = 678
    _globals[
        "_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXUSBBTCONNECTEDTYPE"
    ]._serialized_start = 680
    _globals[
        "_CHARGEBOXCONNECTEDSTATUS_CHARGEBOXUSBBTCONNECTEDTYPE"
    ]._serialized_end = 799
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_gyro.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0eget_gyro.proto\x12\x11insta360.messages"\x18\n\x07GetGyro\x12\r\n\x05\x63ount\x18\x01 \x01(\r"\x1d\n\x0bGetGyroResp\x12\x0e\n\x06gyroes\x18\x01 \x01(\x0c\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "get_gyro_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETGYRO"]._serialized_start = 37
    _globals["_GETGYRO"]._serialized_end = 61
    _globals["_GETGYRORESP"]._serialized_start = 63
    _globals["_GETGYRORESP"]._serialized_end = 92
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_sync_capture_mode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sync_capture_mode_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bget_sync_capture_mode.proto\x12\x11insta360.messages\x1a\x17sync_capture_mode.proto"\x14\n\x12GetSyncCaptureMode"R\n\x16GetSyncCaptureModeResp\x12\x38\n\x0c\x63\x61pture_mode\x18\x01 \x01(\x0e\x32".insta360.messages.SyncCaptureModeB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_sync_capture_mode_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETSYNCCAPTUREMODE"]._serialized_start = 75
    _globals["_GETSYNCCAPTUREMODE"]._serialized_end = 95
    _globals["_GETSYNCCAPTUREMODERESP"]._serialized_start = 97
    _globals["_GETSYNCCAPTUREMODERESP"]._serialized_end = 179
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_file_finish.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from file_type_pb2 import *
from track_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15get_file_finish.proto\x12\x11insta360.messages\x1a\x0f\x66ile_type.proto\x1a\x0btrack.proto"t\n\rGetFileFinish\x12.\n\tfile_type\x18\x01 \x01(\x0e\x32\x1b.insta360.messages.FileType\x12\x33\n\x08\x64ownload\x18\x02 \x01(\x0e\x32!.insta360.messages.TransferStatusB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "get_file_finish_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETFILEFINISH"]._serialized_start = 74
    _globals["_GETFILEFINISH"]._serialized_end = 190
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_whiteblance_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cget_whiteblance_status.proto"\x9b\x01\n\x14GetWhiteblanceStatus\x12\x35\n\x05state\x18\x01 \x01(\x0e\x32&.GetWhiteblanceStatus.WhiteblanceState\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c">\n\x10WhiteblanceState\x12\x12\n\x0e\x42LANCE_UNKNOWN\x10\x00\x12\x16\n\x12\x42LANCE_EXE_SUCCESS\x10\x01\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_whiteblance_status_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETWHITEBLANCESTATUS"]._serialized_start = 33
    _globals["_GETWHITEBLANCESTATUS"]._serialized_end = 188
    _globals["_GETWHITEBLANCESTATUS_WHITEBLANCESTATE"]._serialized_start = 126
    _globals["_GETWHITEBLANCESTATUS_WHITEBLANCESTATE"]._serialized_end = 188
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: track.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from file_type_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0btrack.proto\x12\x11insta360.messages\x1a\x0f\x66ile_type.proto"\xa7\x02\n\nTrackState\x12\x33\n\x0btrack_state\x18\x01 \x01(\x0e\x32\x1e.insta360.messages.TrackStatus\x12\x31\n\tlog_state\x18\x02 \x01(\x0e\x32\x1e.insta360.messages.TrackStatus\x12\x38\n\rexport_status\x18\x03 \x01(\x0e\x32!.insta360.messages.TransferStatus\x12:\n\x0f\x64ownload_status\x18\x04 \x01(\x0e\x32!.insta360.messages.TransferStatus\x12.\n\tfile_type\x18\x05 \x01(\x0e\x32\x1b.insta360.messages.FileType\x12\x0b\n\x03uri\x18\x06 \x01(\t*`\n\x0bTrackStatus\x12\x0e\n\nTrack_IDLE\x10\x00\x12\x0e\n\nTrack_Sync\x10\x01\x12\x0f\n\x0bTrack_Start\x10\x02\x12\r\n\tTrack_End\x10\x03\x12\x11\n\rTrack_Timeout\x10\x04*L\n\x0eTransferStatus\x12\x13\n\x0fTransferUnknown\x10\x00\x12\x13\n\x0fTransferSuccess\x10\x01\x12\x10\n\x0cTransferFail\x10\x02\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "track_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_TRACKSTATUS"]._serialized_start = 349
    _globals["_TRACKSTATUS"]._serialized_end = 445
    _globals["_TRANSFERSTATUS"]._serialized_start = 447
    _globals["_TRANSFERSTATUS"]._serialized_end = 523
    _globals["_TRACKSTATE"]._serialized_start = 52
    _globals["_TRACKSTATE"]._serialized_end = 347
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: button_press.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12\x62utton_press.proto\x12\x11insta360.messages"\xf1\x04\n\x12\x42uttonPressOptions\x12\x31\n\x05\x63lick\x18\x01 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x38\n\x0c\x64ouble_click\x18\x02 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x38\n\x0ctriple_click\x18\x03 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x36\n\nlong_press\x18\x04 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x37\n\x0bshort_press\x18\x05 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12:\n\x0eshutdown_click\x18\x06 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x41\n\x15shutdown_double_click\x18\x07 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12\x41\n\x15shutdown_triple_click\x18\x08 \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12?\n\x13shutdown_long_press\x18\t \x01(\x0e\x32".insta360.messages.ButtonPressMode\x12@\n\x14shutdown_short_press\x18\n \x01(\x0e\x32".insta360.messages.ButtonPressMode"\xff\x03\n\x13\x42uttonFollowOptions\x12\x32\n\x05\x63lick\x18\x01 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12\x39\n\x0c\x64ouble_click\x18\x02 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12\x39\n\x0ctriple_click\x18\x03 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12\x37\n\nlong_press\x18\x04 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12;\n\x0eshutdown_click\x18\x05 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12\x42\n\x15shutdown_double_click\x18\x06 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12\x42\n\x15shutdown_triple_click\x18\x07 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode\x12@\n\x13shutdown_long_press\x18\x08 \x01(\x0e\x32#.insta360.messages.ButtonFollowMode*\xd3\x04\n\x0f\x42uttonPressMode\x12\x11\n\rDO_NOT_CHANGE\x10\x00\x12\x0e\n\nDO_NOTHING\x10\x01\x12\r\n\tSHUT_DOWN\x10\x02\x12\x10\n\x0cTAKE_PICTURE\x10\x03\x12\x0b\n\x07\x43\x41PTURE\x10\x04\x12\r\n\tSELFTIMER\x10\x05\x12\r\n\tTIMELAPSE\x10\x06\x12\x13\n\x0fHIGH_FRAME_RATE\x10\x07\x12\x1a\n\x16\x41\x43TION_TIMELAPSE_VIDEO\x10\x08\x12\x15\n\x11INTERVAL_SHOOTING\x10\t\x12\x19\n\x15\x41\x43TION_INTERVAL_VIDEO\x10\n\x12\x12\n\x0eTAKE_HDR_IMAGE\x10\x0b\x12\x1b\n\x17\x41\x43TION_STATIC_TIMELAPSE\x10\x0c\x12\x19\n\x15\x41\x43TION_CALIBRATE_GYRO\x10\r\x12\x16\n\x12\x41\x43TION_HDR_CAPTURE\x10\x0e\x12\x14\n\x10\x41\x43TION_TIMESHIFT\x10\x0f\x12\x14\n\x10TAKE_BURST_IMAGE\x10\x10\x12\x18\n\x14TAKE_AEB_NIGHT_IMAGE\x10\x11\x12\x11\n\rSUPER_CAPTURE\x10\x12\x12\x18\n\x14\x41\x43TION_LOOPRECORDING\x10\x13\x12\x18\n\x14TAKE_STARLAPSE_IMAGE\x10\x14\x12\x11\n\rFPV_RECORDING\x10\x15\x12\x13\n\x0fMOVIE_RECORDING\x10\x16\x12\x19\n\x15SLOW_MOTION_RECORDING\x10\x17\x12\x14\n\x10SELFIE_RECORDING\x10\x18\x12\x14\n\x10\x46OLLOW_CHARGEBOX\x10\x19\x12\x0e\n\nPURE_VIDEO\x10\x1a*j\n\x10\x42uttonFollowMode\x12\x12\n\x0e\x46OLLOW_UNKNOWN\x10\x00\x12\x0f\n\x0b\x46OLLOW_FULL\x10\x01\x12\x0f\n\x0b\x46OLLOW_PARM\x10\x02\x12\x0f\n\x0b\x46OLLOW_MODE\x10\x03\x12\x0f\n\x0b\x46OLLOW_NONE\x10\x04*\xce\x01\n\x0f\x42uttonPressType\x12\t\n\x05\x43LICK\x10\x00\x12\x10\n\x0c\x44OUBLE_CLICK\x10\x01\x12\x10\n\x0cTRIPLE_CLICK\x10\x02\x12\x0e\n\nLONG_PRESS\x10\x03\x12\x12\n\x0eSHUTDOWN_CLICK\x10\x04\x12\x19\n\x15SHUTDOWN_DOUBLE_CLICK\x10\x05\x12\x19\n\x15SHUTDOWN_TRIPLE_CLICK\x10\x06\x12\x17\n\x13SHUTDOWN_LONG_PRESS\x10\x07\x12\x19\n\x15\x42UTTON_PRESS_TYPE_NUM\x10\x08\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "button_press_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_BUTTONPRESSMODE"]._serialized_start = 1184
    _globals["_BUTTONPRESSMODE"]._serialized_end = 1779
    _globals["_BUTTONFOLLOWMODE"]._serialized_start = 1781
    _globals["_BUTTONFOLLOWMODE"]._serialized_end = 1887
    _globals["_BUTTONPRESSTYPE"]._serialized_start = 1890
    _globals["_BUTTONPRESSTYPE"]._serialized_end = 2096
    _globals["_BUTTONPRESSOPTIONS"]._serialized_start = 42
    _globals["_BUTTONPRESSOPTIONS"]._serialized_end = 667
    _globals["_BUTTONFOLLOWOPTIONS"]._serialized_start = 670
    _globals["_BUTTONFOLLOWOPTIONS"]._serialized_end = 1181
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_live_result.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from camera_live_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18\x63\x61mera_live_result.proto\x12\x11insta360.messages\x1a\x16\x63\x61mera_live_info.proto"\\\n\x10\x43\x61meraLiveResult\x12\x12\n\nerror_code\x18\x01 \x01(\r\x12\x34\n\tlive_info\x18\x02 \x01(\x0b\x32!.insta360.messages.CameraLiveInfoB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "camera_live_result_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERALIVERESULT"]._serialized_start = 71
    _globals["_CAMERALIVERESULT"]._serialized_end = 163
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: heat_shell.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x10heat_shell.proto\x12\x11insta360.messages*'\n\rHeatShellType\x12\x08\n\x04None\x10\x00\x12\x0c\n\x08Standard\x10\x01\x42\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "heat_shell_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_HEATSHELLTYPE"]._serialized_start = 39
    _globals["_HEATSHELLTYPE"]._serialized_end = 78
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sd_card_speed.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13sd_card_speed.proto\x12\x11insta360.messages"F\n\x0fTestSDCardSpeed\x12\x12\n\nblock_size\x18\x01 \x01(\r\x12\x10\n\x08\x64uration\x18\x02 \x01(\r\x12\r\n\x05times\x18\x03 \x01(\r"+\n\x13TestSDCardSpeedResp\x12\x14\n\x0cwrite_speeds\x18\x01 \x03(\x01\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "sd_card_speed_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_TESTSDCARDSPEED"]._serialized_start = 42
    _globals["_TESTSDCARDSPEED"]._serialized_end = 112
    _globals["_TESTSDCARDSPEEDRESP"]._serialized_start = 114
    _globals["_TESTSDCARDSPEEDRESP"]._serialized_end = 157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bt_central.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bluetooth_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x10\x62t_central.proto\x12\x11insta360.messages\x1a\x0f\x62luetooth.proto"P\n\x10ScanBTPeripheral\x12<\n\x0fperipheral_type\x18\x01 \x01(\x0e\x32#.insta360.messages.BTPeripheralType"L\n\x15\x43onnectToBTPeripheral\x12\x33\n\nperipheral\x18\x01 \x01(\x0b\x32\x1f.insta360.messages.BTPeripheral"M\n\x16\x44isconnectBTPeripheral\x12\x33\n\nperipheral\x18\x01 \x01(\x0b\x32\x1f.insta360.messages.BTPeripheral"X\n\x18GetConnectedBTPeripheral\x12<\n\x0fperipheral_type\x18\x01 \x01(\x0e\x32#.insta360.messages.BTPeripheralType"T\n\x1cGetConnectedBTPeripheralResp\x12\x34\n\x0bperipherals\x18\x01 \x03(\x0b\x32\x1f.insta360.messages.BTPeripheralB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "bt_central_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SCANBTPERIPHERAL"]._serialized_start = 56
    _globals["_SCANBTPERIPHERAL"]._serialized_end = 136
    _globals["_CONNECTTOBTPERIPHERAL"]._serialized_start = 138
    _globals["_CONNECTTOBTPERIPHERAL"]._serialized_end = 214
    _globals["_DISCONNECTBTPERIPHERAL"]._serialized_start = 216
    _globals["_DISCONNECTBTPERIPHERAL"]._serialized_end = 293
    _globals["_GETCONNECTEDBTPERIPHERAL"]._serialized_start = 295
    _globals["_GETCONNECTEDBTPERIPHERAL"]._serialized_end = 383
    _globals["_GETCONNECTEDBTPERIPHERALRESP"]._serialized_start = 385
    _globals["_GETCONNECTEDBTPERIPHERALRESP"]._serialized_end = 469
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capture_stopped.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15\x63\x61pture_stopped.proto\x12\x11insta360.messages\x1a\x0bvideo.proto"\xa9\x03\n\x1aNotificationCaptureStopped\x12I\n\x08\x65rr_code\x18\x01 \x01(\x0e\x32\x37.insta360.messages.NotificationCaptureStopped.ErrorCode\x12\'\n\x05video\x18\x02 \x01(\x0b\x32\x18.insta360.messages.Video"\x96\x02\n\tErrorCode\x12\x13\n\x0fOVER_TIME_LIMIT\x10\x00\x12\x10\n\x0cSTORAGE_FULL\x10\x01\x12\x13\n\x0fOTHER_SITUATION\x10\x02\x12\x1a\n\x16OVER_FILE_NUMBER_LIMIT\x10\x03\x12\x12\n\x0eLOW_CARD_SPEED\x10\x04\x12\x16\n\x12MUXER_STREAM_ERROR\x10\x05\x12\x0f\n\x0b\x44ROP_FRAMES\x10\x06\x12\x0f\n\x0bLOW_BATTERY\x10\x07\x12\x10\n\x0cSTORAGEFRGMT\x10\x08\x12\r\n\tHIGH_TEMP\x10\t\x12\x13\n\x0fLOW_POWER_START\x10\n\x12\x18\n\x14STORAGE_RUNOUT_START\x10\x0b\x12\x13\n\x0fHIGH_TEMP_START\x10\x0c\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "capture_stopped_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONCAPTURESTOPPED"]._serialized_start = 58
    _globals["_NOTIFICATIONCAPTURESTOPPED"]._serialized_end = 483
    _globals["_NOTIFICATIONCAPTURESTOPPED_ERRORCODE"]._serialized_start = 205
    _globals["_NOTIFICATIONCAPTURESTOPPED_ERRORCODE"]._serialized_end = 483
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cloud_storage.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x63loud_storage.proto\x12\x11insta360.messages"\x92\x02\n\x18\x43loudStorageUploadParams\x12T\n\rupload_status\x18\x01 \x01(\x0e\x32=.insta360.messages.CloudStorageUploadParams.CloudUploadStatus\x12\x11\n\ttotal_num\x18\x02 \x01(\r\x12\x13\n\x0b\x63urrent_num\x18\x03 \x01(\r\x12\x1b\n\x13is_auto_upload_flag\x18\x04 \x01(\r\x12#\n\x1bis_delete_after_upload_flag\x18\x05 \x01(\r"6\n\x11\x43loudUploadStatus\x12\x08\n\x04NONE\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\x08\n\x04IDLE\x10\x02"\xe7\x02\n\x16\x43loudStorageBindParams\x12N\n\x0b\x62ind_status\x18\x01 \x01(\x0e\x32\x39.insta360.messages.CloudStorageBindParams.CloudBindStatus\x12\x11\n\tuser_name\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x0c\n\x04uuid\x18\x04 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x05 \x01(\t\x12\x12\n\nserial_num\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x07 \x01(\t\x12\x18\n\x10is_token_timeout\x18\x08 \x01(\r\x12\x12\n\ndomain_url\x18\t \x01(\t\x12\x16\n\x0etotal_capacity\x18\n \x01(\x01\x12\x15\n\rused_capacity\x18\x0b \x01(\x01"5\n\x0f\x43loudBindStatus\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x42OUND\x10\x01\x12\r\n\tNOT_BOUND\x10\x02"\x98\x01\n\x12\x43loudStorageStatus\x12>\n\x0b\x62ind_params\x18\x01 \x01(\x0b\x32).insta360.messages.CloudStorageBindParams\x12\x42\n\rupload_params\x18\x02 \x01(\x0b\x32+.insta360.messages.CloudStorageUploadParamsB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "cloud_storage_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CLOUDSTORAGEUPLOADPARAMS"]._serialized_start = 43
    _globals["_CLOUDSTORAGEUPLOADPARAMS"]._serialized_end = 317
    _globals["_CLOUDSTORAGEUPLOADPARAMS_CLOUDUPLOADSTATUS"]._serialized_start = 263
    _globals["_CLOUDSTORAGEUPLOADPARAMS_CLOUDUPLOADSTATUS"]._serialized_end = 317
    _globals["_CLOUDSTORAGEBINDPARAMS"]._serialized_start = 320
    _globals["_CLOUDSTORAGEBINDPARAMS"]._serialized_end = 679
    _globals["_CLOUDSTORAGEBINDPARAMS_CLOUDBINDSTATUS"]._serialized_start = 626
    _globals["_CLOUDSTORAGEBINDPARAMS_CLOUDBINDSTATUS"]._serialized_end = 679
    _globals["_CLOUDSTORAGESTATUS"]._serialized_start = 682
    _globals["_CLOUDSTORAGESTATUS"]._serialized_end = 834
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: temperature.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11temperature.proto\x12\x11insta360.messages"X\n\tTempState\x12\x37\n\ntemp_state\x18\x01 \x01(\x0e\x32#.insta360.messages.TemperatureState\x12\x12\n\ntemp_value\x18\x02 \x01(\x05*h\n\x10TemperatureState\x12\x0c\n\x08TEMP_LOW\x10\x00\x12\x0e\n\nTEMP_ALERT\x10\x01\x12\x0f\n\x0bTEMP_MIDDLE\x10\x02\x12\r\n\tTEMP_HIGH\x10\x03\x12\x16\n\x12TEMP_HIGH_SHUTDOWN\x10\x04\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "temperature_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_TEMPERATURESTATE"]._serialized_start = 130
    _globals["_TEMPERATURESTATE"]._serialized_end = 234
    _globals["_TEMPSTATE"]._serialized_start = 40
    _globals["_TEMPSTATE"]._serialized_end = 128
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capture_state.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x63\x61pture_state.proto\x12\x11insta360.messages*\x85\x05\n\x12\x43\x61meraCaptureState\x12\x0f\n\x0bNOT_CAPTURE\x10\x00\x12\x12\n\x0eNORMAL_CAPTURE\x10\x01\x12\x15\n\x11TIMELAPSE_CAPTURE\x10\x02\x12\x1d\n\x19INTERVAL_SHOOTING_CAPTURE\x10\x03\x12\x13\n\x0fSINGLE_SHOOTING\x10\x04\x12\x10\n\x0cHDR_SHOOTING\x10\x05\x12\x17\n\x13SELF_TIMER_SHOOTING\x10\x06\x12\x17\n\x13\x42ULLET_TIME_CAPTURE\x10\x07\x12\x16\n\x12SETTINGS_NEW_VALUE\x10\x08\x12\x0f\n\x0bHDR_CAPTURE\x10\t\x12\x12\n\x0e\x42URST_SHOOTING\x10\n\x12\x1d\n\x19STATIC_TIMELAPSE_SHOOTING\x10\x0b\x12\x1a\n\x16INTERVAL_VIDEO_CAPTURE\x10\x0c\x12\x15\n\x11TIMESHIFT_CAPTURE\x10\r\x12\x16\n\x12\x41\x45\x42_NIGHT_SHOOTING\x10\x0e\x12\x1e\n\x1aSINGLE_POWER_PANO_SHOOTING\x10\x0f\x12\x1b\n\x17HDR_POWER_PANO_SHOOTING\x10\x10\x12\x18\n\x14SUPER_NORMAL_CAPTURE\x10\x11\x12\x1a\n\x16LOOP_RECORDING_CAPTURE\x10\x12\x12\x16\n\x12STARLAPSE_SHOOTING\x10\x13\x12\x19\n\x15\x46PV_RECORDING_CAPTURE\x10\x14\x12\x1b\n\x17MOVIE_RECORDING_CAPTURE\x10\x15\x12\x17\n\x13SLOW_MOTION_CAPTURE\x10\x16\x12\x1c\n\x18SELFIE_RECORDING_CAPTURE\x10\x17\x12\x1a\n\x16PURE_RECORDING_CAPTURE\x10\x18*\x99\x01\n\x15\x43\x61meraCaptureSubState\x12\x12\n\x0eSUB_STATE_NULL\x10\x00\x12\x13\n\x0fSUB_STATE_PAUSE\x10\x01\x12\x19\n\x15SUB_STATE_RECORD_SAVE\x10\x02\x12\x18\n\x14SUB_STATE_PHOTO_SAVE\x10\x03\x12"\n\x1eSUB_STATE_STARTLAPSE_SYNTHESIS\x10\x04\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "capture_state_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERACAPTURESTATE"]._serialized_start = 43
    _globals["_CAMERACAPTURESTATE"]._serialized_end = 688
    _globals["_CAMERACAPTURESUBSTATE"]._serialized_start = 691
    _globals["_CAMERACAPTURESUBSTATE"]._serialized_end = 844
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_current_button_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capture_state_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fget_current_button_status.proto\x12\x11insta360.messages\x1a\x13\x63\x61pture_state.proto"\xd7\x02\n\x0c\x42uttonStatus\x12:\n\x05state\x18\x01 \x01(\x0e\x32+.insta360.messages.ButtonStatus.ButtonState"\x8a\x02\n\x0b\x42uttonState\x12\x12\n\x0e\x42UTTON_UNKNOWN\x10\x00\x12\x15\n\x11\x42UTTON_POWER_DONW\x10\x01\x12\x15\n\x11\x42UTTON_SHOOT_DONW\x10\x02\x12\x14\n\x10\x42UTTON_BOTH_DONW\x10\x03\x12\x14\n\x10\x42UTTON_NONE_DONW\x10\x04\x12\x19\n\x15\x42UTTON_POWER_PRESS_1S\x10\x05\x12\x19\n\x15\x42UTTON_POWER_PRESS_2S\x10\x06\x12\x1d\n\x19\x42UTTON_POWER_DOUBLE_CLICK\x10\x07\x12\x19\n\x15\x42UTTON_SHOOT_PRESS_1S\x10\x08\x12\x1d\n\x19\x42UTTON_SHOOT_DOUBLE_CLICK\x10\t"M\n\x1aGetCurrentButtonStatusResp\x12/\n\x06status\x18\x01 \x01(\x0b\x32\x1f.insta360.messages.ButtonStatusB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_current_button_status_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_BUTTONSTATUS"]._serialized_start = 76
    _globals["_BUTTONSTATUS"]._serialized_end = 419
    _globals["_BUTTONSTATUS_BUTTONSTATE"]._serialized_start = 153
    _globals["_BUTTONSTATUS_BUTTONSTATE"]._serialized_end = 419
    _globals["_GETCURRENTBUTTONSTATUSRESP"]._serialized_start = 421
    _globals["_GETCURRENTBUTTONSTATUSRESP"]._serialized_end = 498
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_live_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16\x63\x61mera_live_info.proto\x12\x11insta360.messages\x1a\x0bvideo.proto"\xa3\x01\n\x10\x43\x61meraLiveParams\x12\x34\n\tlive_mode\x18\x01 \x01(\x0e\x32!.insta360.messages.CameraLiveMode\x12\x11\n\tlive_addr\x18\x02 \x01(\t\x12\x10\n\x08res_with\x18\x03 \x01(\r\x12\x12\n\nres_height\x18\x04 \x01(\r\x12\x0f\n\x07res_fps\x18\x05 \x01(\r\x12\x0f\n\x07\x62itrate\x18\x06 \x01(\r"\x89\x01\n\x0e\x43\x61meraLiveInfo\x12\x38\n\x0blive_status\x18\x01 \x01(\x0e\x32#.insta360.messages.CameraLiveStatus\x12=\n\x10live_push_params\x18\x02 \x01(\x0b\x32#.insta360.messages.CameraLiveParams*)\n\x10\x43\x61meraLiveStatus\x12\x08\n\x04IDLE\x10\x00\x12\x0b\n\x07LIVEING\x10\x01*/\n\x0e\x43\x61meraLiveMode\x12\x0f\n\x0bLIVE_NORMAL\x10\x00\x12\x0c\n\x08LIVE_HDR\x10\x01\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "camera_live_info_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERALIVESTATUS"]._serialized_start = 364
    _globals["_CAMERALIVESTATUS"]._serialized_end = 405
    _globals["_CAMERALIVEMODE"]._serialized_start = 407
    _globals["_CAMERALIVEMODE"]._serialized_end = 454
    _globals["_CAMERALIVEPARAMS"]._serialized_start = 59
    _globals["_CAMERALIVEPARAMS"]._serialized_end = 222
    _globals["_CAMERALIVEINFO"]._serialized_start = 225
    _globals["_CAMERALIVEINFO"]._serialized_end = 362
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_submode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from photo_pb2 import *
from video_pb2 import *
from sensor_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14\x63\x61mera_submode.proto\x12\x11insta360.messages\x1a\x0bphoto.proto\x1a\x0bvideo.proto\x1a\x0csensor.proto"\xb6\x01\n\x13NotifyCameraSubMode\x12\x36\n\rphoto_submode\x18\x01 \x01(\x0e\x32\x1f.insta360.messages.PhotoSubMode\x12\x36\n\rvideo_submode\x18\x02 \x01(\x0e\x32\x1f.insta360.messages.VideoSubMode\x12/\n\x06sensor\x18\x03 \x01(\x0e\x32\x1f.insta360.messages.SensorDeviceB\x08\xa2\x02\x05INSPBP\x00P\x01P\x02\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "camera_submode_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFYCAMERASUBMODE"]._serialized_start = 84
    _globals["_NOTIFYCAMERASUBMODE"]._serialized_end = 266
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: button_press_params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19\x62utton_press_params.proto\x12\x11insta360.messages\x1a\x0bvideo.proto"\x98\x01\n\x11\x42uttonPressParams\x12J\n\x1e\x62utton_param_record_resolution\x18\x01 \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x1f\n\x17\x62utton_param_lapse_Time\x18\x02 \x01(\r\x12\x16\n\x0erec_limit_time\x18\x03 \x01(\r*\xaf\x01\n\x15\x42uttonPressParamsType\x12\x1f\n\x1b\x42UTTON_PRESS_PARAMS_UNKNOWN\x10\x00\x12"\n\x1e\x42UTTON_PARAM_RECORD_RESOLUTION\x10\x01\x12\x1b\n\x17\x42UTTON_PARAM_LAPSE_TIME\x10\x02\x12\x1e\n\x1a\x42UTTON_PARAM_RES_REC_LIMIT\x10\x03\x12\x14\n\x10\x42UTTON_PARAM_NUM\x10\x04\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "button_press_params_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_BUTTONPRESSPARAMSTYPE"]._serialized_start = 217
    _globals["_BUTTONPRESSPARAMSTYPE"]._serialized_end = 392
    _globals["_BUTTONPRESSPARAMS"]._serialized_start = 62
    _globals["_BUTTONPRESSPARAMS"]._serialized_end = 214
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_camera_live_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from camera_live_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1aset_camera_live_info.proto\x12\x11insta360.messages\x1a\x16\x63\x61mera_live_info.proto"L\n\x11SetCameraLiveInfo\x12\x37\n\nlive_param\x18\x01 \x01(\x0b\x32#.insta360.messages.CameraLiveParams"\x17\n\x15SetCameraLiveInfoRespB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_camera_live_info_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETCAMERALIVEINFO"]._serialized_start = 73
    _globals["_SETCAMERALIVEINFO"]._serialized_end = 149
    _globals["_SETCAMERALIVEINFORESP"]._serialized_start = 151
    _globals["_SETCAMERALIVEINFORESP"]._serialized_end = 174
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wifi_mode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0fwifi_mode.proto\x12\x11insta360.messages"R\n\x0eWifiModeResult\x12.\n\twifi_mode\x18\x01 \x01(\x0e\x32\x1b.insta360.messages.WifiMode\x12\x10\n\x08\x65rr_code\x18\x02 \x01(\x05*$\n\x08WifiMode\x12\x06\n\x02\x41P\x10\x00\x12\x07\n\x03STA\x10\x01\x12\x07\n\x03P2P\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "wifi_mode_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_WIFIMODE"]._serialized_start = 122
    _globals["_WIFIMODE"]._serialized_end = 158
    _globals["_WIFIMODERESULT"]._serialized_start = 38
    _globals["_WIFIMODERESULT"]._serialized_end = 120
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: extra_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from offset_state_pb2 import *
from window_crop_info_pb2 import *
from photo_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x10\x65xtra_info.proto\x12\x11insta360.messages\x1a\x12offset_state.proto\x1a\x16window_crop_info.proto\x1a\x0bphoto.proto"\xe9;\n\rExtraMetadata\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x13\n\x0b\x63\x61mera_type\x18\x02 \x01(\t\x12\x12\n\nfw_version\x18\x03 \x01(\t\x12\x11\n\tfile_type\x18\x04 \x01(\t\x12\x0e\n\x06offset\x18\x05 \x01(\t\x12\n\n\x02ip\x18\x06 \x01(\t\x12\x15\n\rcreation_time\x18\x07 \x01(\x04\x12\x13\n\x0b\x65xport_time\x18\x08 \x01(\x04\x12\x11\n\tfile_size\x18\t \x01(\x04\x12\x12\n\ntotal_time\x18\n \x01(\r\x12\x0b\n\x03gps\x18\x0b \x01(\x0c\x12\x13\n\x0borientation\x18\x0c \x01(\x0c\x12G\n\x0cuser_options\x18\r \x01(\x0b\x32\x31.insta360.messages.ExtraMetadata.ExtraUserOptions\x12\x0c\n\x04gyro\x18\x0e \x01(\x0c\x12=\n\thdr_state\x18\x0f \x01(\x0e\x32*.insta360.messages.ExtraMetadata.HDR_STATE\x12\x16\n\x0ehdr_identifier\x18\x10 \x01(\t\x12\x17\n\x0foriginal_offset\x18\x11 \x01(\t\x12\x46\n\x0etrigger_source\x18\x12 \x01(\x0e\x32..insta360.messages.ExtraMetadata.TriggerSource\x12;\n\tdimension\x18\x13 \x01(\x0b\x32(.insta360.messages.ExtraMetadata.Vector2\x12\x12\n\nframe_rate\x18\x14 \x01(\x05\x12\x41\n\x0fimage_translate\x18\x15 \x01(\x0b\x32(.insta360.messages.ExtraMetadata.Vector2\x12\x12\n\ngamma_mode\x18\x16 \x01(\t\x12H\n\x14thumbnail_gyro_index\x18\x17 \x01(\x0b\x32*.insta360.messages.ExtraMetadata.GyroIndex\x12\x1d\n\x15\x66irst_frame_timestamp\x18\x18 \x01(\x03\x12\x1c\n\x14rolling_shutter_time\x18\x19 \x01(\x01\x12G\n\x0f\x66ile_group_info\x18\x1a \x01(\x0b\x32..insta360.messages.ExtraMetadata.FileGroupInfo\x12;\n\x10window_crop_info\x18\x1b \x01(\x0b\x32!.insta360.messages.WindowCropInfo\x12\x16\n\x0egyro_timestamp\x18\x1c \x01(\x01\x12\x1d\n\x15is_has_gyro_timestamp\x18\x1d \x01(\x08\x12\x1a\n\x12timelapse_interval\x18\x1e \x01(\r\x12\x12\n\ngyro_calib\x18\x1f \x01(\x0c\x12G\n\x0f\x65vo_status_mode\x18  \x01(\x0e\x32..insta360.messages.ExtraMetadata.EvoStatusMode\x12\x15\n\revo_status_id\x18! \x01(\t\x12\x1a\n\x12original_offset_3d\x18" \x01(\t\x12?\n\x0bgps_sources\x18# \x03(\x0e\x32*.insta360.messages.ExtraMetadata.GpsSource\x12\x1b\n\x13\x66irst_gps_timestamp\x18$ \x01(\x03\x12\x19\n\x11orientation_calib\x18% \x01(\x0c\x12\x14\n\x0cis_collected\x18& \x01(\x08\x12\x14\n\x0crecycle_time\x18\' \x01(\x04\x12\x14\n\x0ctotal_frames\x18( \x01(\r\x12\x11\n\tis_selfie\x18) \x01(\x08\x12\x1b\n\x13is_flowstate_online\x18* \x01(\x08\x12\x11\n\tis_dewarp\x18+ \x01(\x08\x12\x41\n\x0fresolution_size\x18, \x01(\x0b\x32(.insta360.messages.ExtraMetadata.Vector2\x12\x43\n\x0c\x62\x61ttery_type\x18- \x01(\x0e\x32-.insta360.messages.ExtraMetadata.Battery_type\x12\x44\n\x0b\x63\x61m_posture\x18. \x01(\x0e\x32/.insta360.messages.ExtraMetadata.Camera_Posture\x12@\n\x08\x66ov_type\x18/ \x01(\x0e\x32..insta360.messages.ExtraMetadata.Image_FovType\x12\x10\n\x08\x64istance\x18\x30 \x01(\x01\x12\x0b\n\x03\x66ov\x18\x31 \x01(\x01\x12J\n\x10gyro_filter_type\x18\x32 \x01(\x0e\x32\x30.insta360.messages.ExtraMetadata.Gyro_FilterType\x12<\n\tgyro_type\x18\x33 \x01(\x0e\x32).insta360.messages.ExtraMetadata.GyroType\x12[\n\x17media_data_rotate_angel\x18\x34 \x01(\x0e\x32:.insta360.messages.ExtraMetadata.VideoMediaDataRotateAngle\x12\x11\n\toffset_v2\x18\x35 \x01(\t\x12\x11\n\toffset_v3\x18\x36 \x01(\t\x12\x1a\n\x12original_offset_v2\x18\x37 \x01(\t\x12\x1a\n\x12original_offset_v3\x18\x38 \x01(\t\x12\x42\n\x0b\x66ocusSensor\x18\x39 \x01(\x0e\x32-.insta360.messages.ExtraMetadata.SensorDevice\x12K\n\x10\x65xpectOutputType\x18: \x01(\x0e\x32\x31.insta360.messages.ExtraMetadata.ExpectOutputType\x12)\n!timelapse_interval_in_millisecond\x18; \x01(\x08\x12\x11\n\tphoto_rot\x18< \x03(\x02\x12\x42\n\naudio_mode\x18= \x01(\x0e\x32..insta360.messages.ExtraMetadata.AudioModeType\x12\x13\n\x0bis_raw_gyro\x18> \x01(\x08\x12;\n\x10raw_capture_type\x18? \x01(\x0e\x32!.insta360.messages.RawCaptureType\x12?\n\x08pts_type\x18@ \x01(\x0e\x32-.insta360.messages.ExtraMetadata.VideoPtsType\x12\x46\n\rgyro_cfg_info\x18\x41 \x01(\x0b\x32/.insta360.messages.ExtraMetadata.GyroConfigInfo\x12\x46\n\x0flens_283M_type1\x18\x42 \x01(\x0e\x32-.insta360.messages.ExtraMetadata.Lens283MType\x12\x46\n\x0flens_283M_type2\x18\x43 \x01(\x0e\x32-.insta360.messages.ExtraMetadata.Lens283MType\x12\x35\n\roffset_states\x18\x44 \x01(\x0e\x32\x1e.insta360.messages.OffsetState\x12\x0f\n\x07q_i_uav\x18\x45 \x03(\x02\x12\x0f\n\x07r_uav_i\x18\x46 \x03(\x02\x12\x46\n\x0e\x61uto_clip_para\x18G \x01(\x0b\x32..insta360.messages.ExtraMetadata.AutoClipParam\x12H\n\x0fmeta_track_para\x18H \x01(\x0b\x32/.insta360.messages.ExtraMetadata.MetaTrackParam\x12>\n\ntime_scale\x18I \x01(\x0e\x32*.insta360.messages.ExtraMetadata.TimeScale\x12I\n\x10hdr_process_type\x18J \x01(\x0e\x32/.insta360.messages.ExtraMetadata.HdrProcessType\x12\x46\n\x0ethumbnail_type\x18K \x01(\x0e\x32..insta360.messages.ExtraMetadata.ThumbnailType\x12S\n\x15pureshot_process_type\x18L \x01(\x0e\x32\x34.insta360.messages.ExtraMetadata.PureShotProcessType\x12\x19\n\x11pre_rec_time_flag\x18M \x01(\x08\x12T\n\x16\x66rame_rate_av_rational\x18N \x01(\x0b\x32\x34.insta360.messages.ExtraMetadata.FrameRateAVRational\x1a\xde\x04\n\x10\x45xtraUserOptions\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x10\n\x08\x62\x65\x66ilter\x18\x02 \x01(\t\x12\r\n\x05\x65uler\x18\x03 \x01(\x0c\x12\x11\n\trm_purple\x18\x04 \x01(\x08\x12\x1b\n\x13gyro_calibrate_mode\x18\x05 \x01(\r\x12\x14\n\x0c\x65uler_enable\x18\x06 \x01(\x08\x12M\n\tlogo_type\x18\x07 \x01(\x0e\x32:.insta360.messages.ExtraMetadata.ExtraUserOptions.LogoType\x12\x15\n\radjustFilters\x18\x08 \x01(\t\x12\x12\n\nlut_filter\x18\t \x01(\t\x12\x63\n\x15offset_convert_states\x18\n \x03(\x0e\x32\x44.insta360.messages.ExtraMetadata.ExtraUserOptions.OffsetConvertState\x12%\n\x1dplay_trim_recommend_timestamp\x18\x0b \x01(\x01">\n\x08LogoType\x12\x15\n\x11UNKNOWN_LOGO_TYPE\x10\x00\x12\x0b\n\x07NO_LOGO\x10\x01\x12\x0e\n\nINSTA_LOGO\x10\x02"\x8c\x01\n\x12OffsetConvertState\x12\x0e\n\nWaterProof\x10\x00\x12\x0f\n\x0b\x44ivingWater\x10\x01\x12\r\n\tDivingAir\x10\x02\x12\x16\n\x12StitchOptimization\x10\x03\x12\x0b\n\x07Protect\x10\x04\x12\x11\n\rSphereProtect\x10\x05\x12\x0e\n\nFpvProtect\x10\x06\x1a\x1f\n\x07Vector2\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x1a-\n\tGyroIndex\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x1a|\n\rFileGroupInfo\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.insta360.messages.ExtraMetadata.SubMediaType\x12\r\n\x05index\x18\x02 \x01(\r\x12\x10\n\x08identify\x18\x03 \x01(\t\x12\r\n\x05total\x18\x04 \x01(\r\x1a\x37\n\x0eGyroConfigInfo\x12\x11\n\tacc_range\x18\x01 \x01(\r\x12\x12\n\ngyro_range\x18\x02 \x01(\r\x1a\xa2\x02\n\rAutoClipParam\x12\x41\n\x07version\x18\x01 \x01(\x0b\x32\x30.insta360.messages.ExtraMetadata.AutoClipVersion\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x02\x12\r\n\x05img_w\x18\x03 \x01(\r\x12\r\n\x05img_h\x18\x04 \x01(\r\x12\x11\n\timg_pitch\x18\x05 \x01(\r\x12\x42\n\x0c\x63ompute_type\x18\x06 \x01(\x0e\x32,.insta360.messages.ExtraMetadata.ComputeType\x12\x0b\n\x03\x66ps\x18\x07 \x01(\r\x12\x10\n\x08seq_diff\x18\x08 \x01(\r\x12\x10\n\x08pts_diff\x18\t \x01(\r\x12\x13\n\x0btotal_frame\x18\n \x01(\r\x1aL\n\x0eMetaTrackParam\x12\x13\n\x0bImuDataSize\x18\x01 \x01(\x04\x12\x13\n\x0b\x41\x41\x41\x44\x61taSize\x18\x02 \x01(\x04\x12\x10\n\x08\x43ompress\x18\x03 \x01(\r\x1a/\n\x13\x46rameRateAVRational\x12\x0b\n\x03num\x18\x01 \x01(\r\x12\x0b\n\x03\x64\x65n\x18\x02 \x01(\r\x1a;\n\x0c\x41iLibVersion\x12\r\n\x05major\x18\x01 \x01(\r\x12\r\n\x05minor\x18\x02 \x01(\r\x12\r\n\x05patch\x18\x03 \x01(\r\x1a\x93\x02\n\x0f\x41utoClipVersion\x12=\n\x08platform\x18\x01 \x01(\x0e\x32+.insta360.messages.ExtraMetadata.AiPlatform\x12?\n\talgorithm\x18\x02 \x01(\x0e\x32,.insta360.messages.ExtraMetadata.AiAlgorithm\x12@\n\tmodel_ver\x18\x03 \x01(\x0b\x32-.insta360.messages.ExtraMetadata.AiLibVersion\x12>\n\x07svc_ver\x18\x04 \x01(\x0b\x32-.insta360.messages.ExtraMetadata.AiLibVersion"<\n\tHDR_STATE\x12\x0b\n\x07NOT_HDR\x10\x00\x12\x13\n\x0fWAITING_PROCESS\x10\x01\x12\r\n\tPROCESSED\x10\x02"X\n\rTriggerSource\x12\x0b\n\x07Unknown\x10\x00\x12\x10\n\x0c\x43\x61meraButton\x10\x01\x12\x11\n\rRemoteControl\x10\x02\x12\x07\n\x03USB\x10\x03\x12\x0c\n\x08\x42tRemote\x10\x04"F\n\rEvoStatusMode\x12\x17\n\x13UNKNOWN_STATUS_MODE\x10\x00\x12\r\n\tDEGREE180\x10\x01\x12\r\n\tDEGREE360\x10\x02"/\n\tGpsSource\x12\x07\n\x03GSV\x10\x00\x12\r\n\tDASHBOARD\x10\x01\x12\n\n\x06REMOTE\x10\x02"1\n\x0c\x42\x61ttery_type\x12\t\n\x05THICK\x10\x00\x12\x08\n\x04THIN\x10\x01\x12\x0c\n\x08VERTICAL\x10\x02"i\n\x0e\x43\x61mera_Posture\x12\x13\n\x0f\x43\x41MERA_ROTATE_0\x10\x00\x12\x14\n\x10\x43\x41MERA_ROTATE_90\x10\x01\x12\x15\n\x11\x43\x41MERA_ROTATE_180\x10\x02\x12\x15\n\x11\x43\x41MERA_ROTATE_270\x10\x03"\xad\x02\n\rImage_FovType\x12\x14\n\x10\x46OV_TYPE_UNKNOWN\x10\x00\x12\x11\n\rFOV_TYPE_WIDE\x10\x01\x12\x13\n\x0f\x46OV_TYPE_LINEAR\x10\x02\x12\x16\n\x12\x46OV_TYPE_ULTRAWIDE\x10\x03\x12\x13\n\x0f\x46OV_TYPE_NARROW\x10\x04\x12\x10\n\x0c\x46OV_TYPE_POV\x10\x05\x12\x17\n\x13\x46OV_TYPE_LINEARPLUS\x10\x06\x12\x1a\n\x16\x46OV_TYPE_LINEARHORIZON\x10\x07\x12\x10\n\x0c\x46OV_TYPE_FPV\x10\x08\x12\x12\n\x0e\x46OV_TYPE_SUPER\x10\t\x12\x17\n\x13\x46OV_TYPE_TINYPLANET\x10\n\x12\x19\n\x15\x46OV_TYPE_INFINITYWIDE\x10\x0b\x12\x10\n\x0c\x46OV_TYPE_NUM\x10\x0c"e\n\x0fGyro_FilterType\x12\x1c\n\x18GYRO_FILTER_TYPE_UNKNOWN\x10\x00\x12\x1a\n\x16GYRO_FILTER_TYPE_BRUTE\x10\x01\x12\x18\n\x14GYRO_FILTER_TYPE_AKF\x10\x02"@\n\x08GyroType\x12\x19\n\x15INSDEV_IMU_TYPE_20948\x10\x00\x12\x19\n\x15INSDEV_IMU_TYPE_40609\x10\x01"\xbb\x01\n\x19VideoMediaDataRotateAngle\x12\x1d\n\x19MEDIA_DATA_ROTATE_UNKNOWN\x10\x00\x12\x1d\n\x19MEDIA_DATA_ROTATE_ANGLE_0\x10\x01\x12\x1f\n\x1bMEDIA_DATA_ROTATE_ANGLE_180\x10\x03\x12\x1e\n\x1aMEDIA_DATA_ROTATE_ANGLE_90\x10\x06\x12\x1f\n\x1bMEDIA_DATA_ROTATE_ANGLE_270\x10\x08"q\n\x0cSensorDevice\x12\x19\n\x15SENSOR_DEVICE_UNKNOWN\x10\x00\x12\x17\n\x13SENSOR_DEVICE_FRONT\x10\x01\x12\x16\n\x12SENSOR_DEVICE_REAR\x10\x02\x12\x15\n\x11SENSOR_DEVICE_ALL\x10\x03"O\n\x10\x45xpectOutputType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0e\n\nINSTA_PANO\x10\x01\x12\x10\n\x0cMULTI_CAMERA\x10\x02\x12\x0c\n\x08ONE_TAKE\x10\x03"\xec\x01\n\rAudioModeType\x12\x16\n\x12\x41UDIO_MODE_UNKNOWN\x10\x00\x12\x14\n\x10\x41UDIO_MODE_FOCUS\x10\x01\x12\x1c\n\x18\x41UDIO_MODE_WINDREDUCTION\x10\x02\x12\x12\n\x0e\x41UDIO_MODE_360\x10\x03\x12\x15\n\x11\x41UDIO_MODE_STEREO\x10\x04\x12\x18\n\x14\x41UDIO_MODE_EXTMICDEV\x10\x05\x12\x18\n\x14\x41UDIO_MODE_AIRPODDEV\x10\x06\x12\x17\n\x13\x41UDIO_MODE_RESERVE1\x10\x07\x12\x17\n\x13\x41UDIO_MODE_RESERVE2\x10\x08"U\n\x0cVideoPtsType\x12\x15\n\x11VIDEO_PTS_UNKNOWN\x10\x00\x12\x11\n\rVIDEO_PTS_MP4\x10\x01\x12\x1b\n\x17VIDEO_PTS_EXPOSURE_FILE\x10\x02"V\n\x0cLens283MType\x12\x0f\n\x0bLENS_UNKNOW\x10\x00\x12\x19\n\x15LENS_LOW_TRANSPARENCY\x10\x01\x12\x1a\n\x16LENS_HIGH_TRANSPARENCY\x10\x02"i\n\tTimeScale\x12\x10\n\x0cTIMESCALE_1X\x10\x00\x12\x10\n\x0cTIMESCALE_4X\x10\x01\x12\x10\n\x0cTIMESCALE_8X\x10\x02\x12\x12\n\x0eTIMESCALE_1_4X\x10\x03\x12\x12\n\x0eTIMESCALE_1_8X\x10\x04"A\n\x0eHdrProcessType\x12\x18\n\x14HDR_PROCESS_EXTERNAL\x10\x00\x12\x15\n\x11HDR_PROCESS_INNER\x10\x01"u\n\rThumbnailType\x12\x1a\n\x16THUMBNAIL_TYPE_UNKNOWN\x10\x00\x12\x16\n\x12THUMBNAIL_TYPE_YUV\x10\x01\x12\x17\n\x13THUMBNAIL_TYPE_JPEG\x10\x02\x12\x17\n\x13THUMBNAIL_TYPE_H264\x10\x03"P\n\x13PureShotProcessType\x12\x1d\n\x19PURESHOT_PROCESS_EXTERNAL\x10\x00\x12\x1a\n\x16PURESHOT_PROCESS_INNER\x10\x01"\xd3\x03\n\x0cSubMediaType\x12\x10\n\x0cVIDEO_NORMAL\x10\x00\x12\x14\n\x10VIDEO_BULLETTIME\x10\x01\x12\x13\n\x0fVIDEO_TIMELAPSE\x10\x02\x12\x10\n\x0cPHOTO_NORMAL\x10\x03\x12\r\n\tPHOTO_HDR\x10\x04\x12\x1a\n\x16PHOTO_INTERVALSHOOTING\x10\x05\x12\r\n\tVIDEO_HDR\x10\x06\x12\x0f\n\x0bPHOTO_BURST\x10\x07\x12\x1a\n\x16VIDEO_STATIC_TIMELAPSE\x10\x08\x12\x13\n\x0fVIDEO_TIMESHIFT\x10\t\x12\x18\n\x14PHOTO_AEB_NIGHT_MODE\x10\n\x12\x16\n\x12VIDEO_SUPER_NORMAL\x10\x0b\x12\x17\n\x13VIDEO_LOOPRECORDING\x10\x0c\x12\x13\n\x0fPHOTO_STARLAPSE\x10\r\x12\x13\n\x0fPHOTO_PANO_MODE\x10\x0e\x12\r\n\tVIDEO_FPV\x10\x0f\x12\x0f\n\x0bVIDEO_MOVIE\x10\x10\x12\x14\n\x10VIDEO_SLOWMOTION\x10\x11\x12\x10\n\x0cVIDEO_SELFIE\x10\x12\x12\x16\n\x12PHOTO_PURESHOTPLUS\x10\x13\x12\x0e\n\nVIDEO_PURE\x10\x14\x12\x13\n\x0fVIDEO_STARLAPSE\x10\x15"\x19\n\x0b\x41iAlgorithm\x12\n\n\x06\x45\x44ITOR\x10\x00"(\n\nAiPlatform\x12\x07\n\x03\x43V5\x10\x00\x12\x08\n\x04\x43V22\x10\x01\x12\x07\n\x03H22\x10\x02"@\n\x0b\x43omputeType\x12\x0f\n\x0b\x43OMPUTE_CPU\x10\x00\x12\x0f\n\x0b\x43OMPUTE_VPU\x10\x01\x12\x0f\n\x0b\x43OMPUTE_DSP\x10\x02"\x8a\x01\n\x15\x46ileExtraMetadataResp\x12\x0b\n\x03uri\x18\x01 \x03(\t\x12\x33\n\tmediaData\x18\x02 \x03(\x0b\x32 .insta360.messages.ExtraMetadata\x12\x13\n\x0btotal_count\x18\x03 \x01(\r\x12\r\n\x05start\x18\x04 \x01(\r\x12\x0b\n\x03\x65nd\x18\x05 \x01(\r*\xc0\x03\n\tExtraType\x12\x12\n\x0e\x45XTRA_TYPE_ALL\x10\x00\x12\x17\n\x13\x45XTRA_TYPE_METADATA\x10\x01\x12\x18\n\x14\x45XTRA_TYPE_THUMBNAIL\x10\x02\x12\x13\n\x0f\x45XTRA_TYPE_GYRO\x10\x03\x12\x17\n\x13\x45XTRA_TYPE_EXPOSURE\x10\x04\x12\x1c\n\x18\x45XTRA_TYPE_EXT_THUMBNAIL\x10\x05\x12\x18\n\x14\x45XTRA_TYPE_FRAME_PTS\x10\x06\x12\x12\n\x0e\x45XTRA_TYPE_GPS\x10\x07\x12\x17\n\x13\x45XTRA_TYPE_STAR_NUM\x10\x08\x12\x17\n\x13\x45XTRA_TYPE_AAA_DATA\x10\t\x12\x18\n\x14\x45XTRA_TYPE_HIGHLIGHT\x10\n\x12\x16\n\x12\x45XTRA_TYPE_AAA_SIM\x10\x0b\x12\x1c\n\x18\x45XTRA_TYPE_EXPOTIME_VIN1\x10\x0c\x12\x17\n\x13\x45XTRA_TYPE_MAGNETIC\x10\r\x12\x14\n\x10\x45XTRA_TYPE_EULER\x10\x0e\x12\x16\n\x12\x45XTRA_TYPE_SECGYRO\x10\x0f\x12\x14\n\x10\x45XTRA_TYPE_SPEED\x10\x10\x12\x13\n\x0f\x45XTRA_TYPE_TBOX\x10\x11\x42\x08\xa2\x02\x05INSPBP\x00P\x01P\x02\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "extra_info_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_EXTRATYPE"]._serialized_start = 7898
    _globals["_EXTRATYPE"]._serialized_end = 8346
    _globals["_EXTRAMETADATA"]._serialized_start = 97
    _globals["_EXTRAMETADATA"]._serialized_end = 7754
    _globals["_EXTRAMETADATA_EXTRAUSEROPTIONS"]._serialized_start = 3442
    _globals["_EXTRAMETADATA_EXTRAUSEROPTIONS"]._serialized_end = 4048
    _globals["_EXTRAMETADATA_EXTRAUSEROPTIONS_LOGOTYPE"]._serialized_start = 3843
    _globals["_EXTRAMETADATA_EXTRAUSEROPTIONS_LOGOTYPE"]._serialized_end = 3905
    _globals[
        "_EXTRAMETADATA_EXTRAUSEROPTIONS_OFFSETCONVERTSTATE"
    ]._serialized_start = 3908
    _globals[
        "_EXTRAMETADATA_EXTRAUSEROPTIONS_OFFSETCONVERTSTATE"
    ]._serialized_end = 4048
    _globals["_EXTRAMETADATA_VECTOR2"]._serialized_start = 4050
    _globals["_EXTRAMETADATA_VECTOR2"]._serialized_end = 4081
    _globals["_EXTRAMETADATA_GYROINDEX"]._serialized_start = 4083
    _globals["_EXTRAMETADATA_GYROINDEX"]._serialized_end = 4128
    _globals["_EXTRAMETADATA_FILEGROUPINFO"]._serialized_start = 4130
    _globals["_EXTRAMETADATA_FILEGROUPINFO"]._serialized_end = 4254
    _globals["_EXTRAMETADATA_GYROCONFIGINFO"]._serialized_start = 4256
    _globals["_EXTRAMETADATA_GYROCONFIGINFO"]._serialized_end = 4311
    _globals["_EXTRAMETADATA_AUTOCLIPPARAM"]._serialized_start = 4314
    _globals["_EXTRAMETADATA_AUTOCLIPPARAM"]._serialized_end = 4604
    _globals["_EXTRAMETADATA_METATRACKPARAM"]._serialized_start = 4606
    _globals["_EXTRAMETADATA_METATRACKPARAM"]._serialized_end = 4682
    _globals["_EXTRAMETADATA_FRAMERATEAVRATIONAL"]._serialized_start = 4684
    _globals["_EXTRAMETADATA_FRAMERATEAVRATIONAL"]._serialized_end = 4731
    _globals["_EXTRAMETADATA_AILIBVERSION"]._serialized_start = 4733
    _globals["_EXTRAMETADATA_AILIBVERSION"]._serialized_end = 4792
    _globals["_EXTRAMETADATA_AUTOCLIPVERSION"]._serialized_start = 4795
    _globals["_EXTRAMETADATA_AUTOCLIPVERSION"]._serialized_end = 5070
    _globals["_EXTRAMETADATA_HDR_STATE"]._serialized_start = 5072
    _globals["_EXTRAMETADATA_HDR_STATE"]._serialized_end = 5132
    _globals["_EXTRAMETADATA_TRIGGERSOURCE"]._serialized_start = 5134
    _globals["_EXTRAMETADATA_TRIGGERSOURCE"]._serialized_end = 5222
    _globals["_EXTRAMETADATA_EVOSTATUSMODE"]._serialized_start = 5224
    _globals["_EXTRAMETADATA_EVOSTATUSMODE"]._serialized_end = 5294
    _globals["_EXTRAMETADATA_GPSSOURCE"]._serialized_start = 5296
    _globals["_EXTRAMETADATA_GPSSOURCE"]._serialized_end = 5343
    _globals["_EXTRAMETADATA_BATTERY_TYPE"]._serialized_start = 5345
    _globals["_EXTRAMETADATA_BATTERY_TYPE"]._serialized_end = 5394
    _globals["_EXTRAMETADATA_CAMERA_POSTURE"]._serialized_start = 5396
    _globals["_EXTRAMETADATA_CAMERA_POSTURE"]._serialized_end = 5501
    _globals["_EXTRAMETADATA_IMAGE_FOVTYPE"]._serialized_start = 5504
    _globals["_EXTRAMETADATA_IMAGE_FOVTYPE"]._serialized_end = 5805
    _globals["_EXTRAMETADATA_GYRO_FILTERTYPE"]._serialized_start = 5807
    _globals["_EXTRAMETADATA_GYRO_FILTERTYPE"]._serialized_end = 5908
    _globals["_EXTRAMETADATA_GYROTYPE"]._serialized_start = 5910
    _globals["_EXTRAMETADATA_GYROTYPE"]._serialized_end = 5974
    _globals["_EXTRAMETADATA_VIDEOMEDIADATAROTATEANGLE"]._serialized_start = 5977
    _globals["_EXTRAMETADATA_VIDEOMEDIADATAROTATEANGLE"]._serialized_end = 6164
    _globals["_EXTRAMETADATA_SENSORDEVICE"]._serialized_start = 6166
    _globals["_EXTRAMETADATA_SENSORDEVICE"]._serialized_end = 6279
    _globals["_EXTRAMETADATA_EXPECTOUTPUTTYPE"]._serialized_start = 6281
    _globals["_EXTRAMETADATA_EXPECTOUTPUTTYPE"]._serialized_end = 6360
    _globals["_EXTRAMETADATA_AUDIOMODETYPE"]._serialized_start = 6363
    _globals["_EXTRAMETADATA_AUDIOMODETYPE"]._serialized_end = 6599
    _globals["_EXTRAMETADATA_VIDEOPTSTYPE"]._serialized_start = 6601
    _globals["_EXTRAMETADATA_VIDEOPTSTYPE"]._serialized_end = 6686
    _globals["_EXTRAMETADATA_LENS283MTYPE"]._serialized_start = 6688
    _globals["_EXTRAMETADATA_LENS283MTYPE"]._serialized_end = 6774
    _globals["_EXTRAMETADATA_TIMESCALE"]._serialized_start = 6776
    _globals["_EXTRAMETADATA_TIMESCALE"]._serialized_end = 6881
    _globals["_EXTRAMETADATA_HDRPROCESSTYPE"]._serialized_start = 6883
    _globals["_EXTRAMETADATA_HDRPROCESSTYPE"]._serialized_end = 6948
    _globals["_EXTRAMETADATA_THUMBNAILTYPE"]._serialized_start = 6950
    _globals["_EXTRAMETADATA_THUMBNAILTYPE"]._serialized_end = 7067
    _globals["_EXTRAMETADATA_PURESHOTPROCESSTYPE"]._serialized_start = 7069
    _globals["_EXTRAMETADATA_PURESHOTPROCESSTYPE"]._serialized_end = 7149
    _globals["_EXTRAMETADATA_SUBMEDIATYPE"]._serialized_start = 7152
    _globals["_EXTRAMETADATA_SUBMEDIATYPE"]._serialized_end = 7619
    _globals["_EXTRAMETADATA_AIALGORITHM"]._serialized_start = 7621
    _globals["_EXTRAMETADATA_AIALGORITHM"]._serialized_end = 7646
    _globals["_EXTRAMETADATA_AIPLATFORM"]._serialized_start = 7648
    _globals["_EXTRAMETADATA_AIPLATFORM"]._serialized_end = 7688
    _globals["_EXTRAMETADATA_COMPUTETYPE"]._serialized_start = 7690
    _globals["_EXTRAMETADATA_COMPUTETYPE"]._serialized_end = 7754
    _globals["_FILEEXTRAMETADATARESP"]._serialized_start = 7757
    _globals["_FILEEXTRAMETADATARESP"]._serialized_end = 7895
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from photo_pb2 import *
from video_pb2 import *
from battery_pb2 import *
from storage_pb2 import *
from button_press_pb2 import *
from flicker_pb2 import *
from sensor_pb2 import *
from chargebox_pb2 import *
from offset_state_pb2 import *
from window_crop_info_pb2 import *
from heat_shell_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\roptions.proto\x12\x11insta360.messages\x1a\x0bphoto.proto\x1a\x0bvideo.proto\x1a\rbattery.proto\x1a\rstorage.proto\x1a\x12\x62utton_press.proto\x1a\rflicker.proto\x1a\x0csensor.proto\x1a\x0f\x63hargebox.proto\x1a\x12offset_state.proto\x1a\x16window_crop_info.proto\x1a\x10heat_shell.proto"\x91/\n\x07Options\x12<\n\x10video_resolution\x18\x01 \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x30\n\nphoto_size\x18\x02 \x01(\x0e\x32\x1c.insta360.messages.PhotoSize\x12\x15\n\rvideo_bitrate\x18\x03 \x01(\r\x12\x15\n\raudio_bitrate\x18\x04 \x01(\r\x12\x18\n\x10\x61udio_samplerate\x18\x05 \x01(\r\x12\x15\n\rorigin_offset\x18\x06 \x01(\t\x12\x1a\n\x12\x63\x61pture_time_limit\x18\x07 \x01(\r\x12\x13\n\x0bgps_timeout\x18\x08 \x01(\r\x12\x1e\n\x16remaining_capture_time\x18\t \x01(\r\x12\x1a\n\x12remaining_pictures\x18\n \x01(\r\x12\x38\n\x0e\x62\x61ttery_status\x18\x0b \x01(\x0b\x32 .insta360.messages.BatteryStatus\x12\x12\n\nlocal_time\x18\x0c \x01(\x04\x12"\n\x1atime_zone_seconds_from_GMT\x18\r \x01(\x05\x12\x0c\n\x04mute\x18\x0e \x01(\x08\x12\x15\n\rserial_number\x18\x0f \x01(\t\x12\x0c\n\x04UUID\x18\x10 \x01(\t\x12;\n\x0cpressOptions\x18\x11 \x01(\x0b\x32%.insta360.messages.ButtonPressOptions\x12\x15\n\ractivate_time\x18\x13 \x01(\x04\x12\x36\n\rstorage_state\x18\x14 \x01(\x0b\x32\x1f.insta360.messages.StorageState\x12\x12\n\nlens_index\x18\x15 \x01(\r\x12\x14\n\x0cmedia_offset\x18\x16 \x01(\t\x12\x12\n\nself_timer\x18\x17 \x01(\r\x12\x18\n\x10gyro_sample_rate\x18\x18 \x01(\r\x12?\n\tacc_range\x18\x19 \x01(\x0e\x32,.insta360.messages.Options.AccFullScaleRange\x12\x41\n\ngyro_range\x18\x1a \x01(\x0e\x32-.insta360.messages.Options.GyroFullScaleRange\x12\x18\n\x10take_raw_picture\x18\x1b \x01(\x08\x12\x30\n\ngamma_mode\x18\x1c \x01(\x0e\x32\x1c.insta360.messages.GammaMode\x12\x12\n\nmedia_time\x18\x1d \x01(\x03\x12\x18\n\x10\x66irmwareRevision\x18\x1e \x01(\t\x12?\n\x0csys_adoption\x18\x1f \x01(\x0e\x32).insta360.messages.Options.AdoptionSystem\x12\x10\n\x08\x63pu_type\x18  \x01(\t\x12G\n\x12gyro_filter_config\x18! \x01(\x0b\x32+.insta360.messages.Options.GyroFilterConfig\x12\x13\n\x0bmctf_enable\x18" \x01(\x08\x12\x19\n\x11sport_mode_enable\x18# \x01(\x08\x12\x36\n\twifi_info\x18$ \x01(\x0b\x32#.insta360.messages.Options.WifiInfo\x12\x45\n\x11wifi_channel_list\x18% \x01(\x0b\x32*.insta360.messages.Options.WifiChannelList\x12\x18\n\x10\x61uthorization_id\x18& \x01(\t\x12\x1a\n\x12\x63\x61libration_offset\x18\' \x01(\t\x12\x37\n\x0ephoto_sub_mode\x18( \x01(\x0e\x32\x1f.insta360.messages.PhotoSubMode\x12\x37\n\x0evideo_sub_mode\x18) \x01(\x0e\x32\x1f.insta360.messages.VideoSubMode\x12=\n\x11second_stream_res\x18* \x01(\x0e\x32".insta360.messages.VideoResolution\x12:\n\x0bwifi_status\x18+ \x01(\x0e\x32%.insta360.messages.Options.WifiStatus\x12\x41\n\x0f\x65vo_status_mode\x18, \x01(\x0e\x32(.insta360.messages.Options.EvoStatusMode\x12\x18\n\x10origin_offset_3d\x18- \x01(\t\x12\x17\n\x0fmedia_offset_3d\x18. \x01(\t\x12\x1d\n\x15\x63\x61libration_offset_3d\x18/ \x01(\t\x12\x13\n\x0b\x63\x61mera_type\x18\x30 \x01(\t\x12\x19\n\x11\x62t_remote_version\x18\x31 \x01(\t\x12?\n\x0e\x62t_remote_type\x18\x32 \x01(\x0e\x32\'.insta360.messages.Options.BTRemoteType\x12\x42\n\x0fquality_setting\x18\x33 \x01(\x0e\x32).insta360.messages.Options.QualitySetting\x12\x1c\n\x14over_heat_protection\x18\x34 \x01(\x08\x12\x1f\n\x17\x63\x61libration_orientation\x18\x35 \x01(\x0c\x12\x18\n\x10standby_duration\x18\x36 \x01(\r\x12\x1c\n\x14quick_capture_enable\x18\x37 \x01(\x08\x12\x13\n\x0b\x62t_mac_addr\x18\x38 \x01(\t\x12\x46\n\x11television_system\x18\x39 \x01(\x0e\x32+.insta360.messages.Options.TelevisionSystem\x12\x1c\n\x14sensor0_serial_vr360\x18: \x01(\t\x12\x1c\n\x14sensor1_serial_vr360\x18; \x01(\t\x12\x1b\n\x13sensor_serial_vr180\x18< \x01(\t\x12\x16\n\x0emobvoi_license\x18= \x01(\t\x12\x19\n\x11mobvoi_public_key\x18> \x01(\t\x12\x36\n\tgyro_info\x18? \x01(\x0b\x32#.insta360.messages.Options.GyroInfo\x12\x11\n\tsensor_id\x18@ \x01(\t\x12\x1f\n\x17\x65nableInternalFlowstate\x18\x41 \x01(\x08\x12\x45\n\x11video_encode_type\x18\x42 \x01(\x0e\x32*.insta360.messages.Options.VideoEncodeType\x12)\n\x06sensor\x18\x43 \x01(\x0b\x32\x19.insta360.messages.Sensor\x12\x11\n\tis_selfie\x18\x44 \x01(\x08\x12\x1c\n\x14rolling_shutter_time\x18\x45 \x01(\x01\x12\x16\n\x0egyro_timestamp\x18\x46 \x01(\x01\x12-\n\tvideo_fov\x18G \x01(\x0e\x32\x1a.insta360.messages.FovType\x12-\n\tstill_fov\x18H \x01(\x0e\x32\x1a.insta360.messages.FovType\x12\x1a\n\x12Gyro_Polyfit_State\x18I \x01(\x08\x12\x1c\n\x14Gyro_Calibrate_State\x18J \x01(\x08\x12#\n\x1bmobvoi_license_verity_state\x18K \x01(\x08\x12+\n\x07\x66licker\x18L \x01(\x0e\x32\x1a.insta360.messages.Flicker\x12\x12\n\ntemp_value\x18M \x01(\x05\x12\x18\n\x10origin_offset_v2\x18N \x01(\t\x12\x18\n\x10origin_offset_v3\x18O \x01(\t\x12\x17\n\x0fmedia_offset_v2\x18P \x01(\t\x12\x17\n\x0fmedia_offset_v3\x18Q \x01(\t\x12\x34\n\x0b\x66ocusSensor\x18R \x01(\x0e\x32\x1f.insta360.messages.SensorDevice\x12\x45\n\x10\x65xpectOutputType\x18S \x01(\x0e\x32+.insta360.messages.Options.ExpectOutputType\x12\x32\n\x07hw_type\x18T \x01(\x0e\x32!.insta360.messages.Options.HwType\x12M\n\x18\x43hargeboxConnectedStatus\x18U \x01(\x0b\x32+.insta360.messages.ChargeboxConnectedStatus\x12\x41\n\x0f\x63\x61mera_language\x18X \x01(\x0e\x32(.insta360.messages.Options.LANGUAGE_TYPE\x12\x13\n\x0b\x62le_version\x18Y \x01(\t\x12\x44\n\x0e\x63\x61mera_posture\x18] \x01(\x0e\x32,.insta360.messages.Options.CameraPostureType\x12=\n\x0c\x62t_wakeup_sw\x18\x61 \x01(\x0e\x32\'.insta360.messages.Options.Bt_Wakeup_Sw\x12\x35\n\roffset_states\x18g \x01(\x0e\x32\x1e.insta360.messages.OffsetState\x12\x17\n\x0fota_pkg_version\x18n \x01(\t\x12\x1b\n\x13\x62ox_ota_pkg_version\x18r \x01(\t\x12\x16\n\x0e\x62ox_bt_version\x18s \x01(\t\x12\x13\n\x0b\x62ox_version\x18t \x01(\t\x12\x13\n\x0bgo3_version\x18u \x01(\t\x12\x1b\n\x13wifi_working_status\x18v \x01(\x08\x12=\n\rfollowOptions\x18w \x01(\x0b\x32&.insta360.messages.ButtonFollowOptions\x12\x12\n\nled_switch\x18x \x01(\x08\x12W\n!camera_posture_when_capture_start\x18z \x01(\x0e\x32,.insta360.messages.Options.CameraPostureType\x12\x62\n-chargebox_connected_status_when_capture_start\x18{ \x01(\x0b\x32+.insta360.messages.ChargeboxConnectedStatus\x12;\n\x10window_crop_info\x18| \x01(\x0b\x32!.insta360.messages.WindowCropInfo\x12\x1e\n\x15\x61ssistive_grid_enable\x18\x80\x01 \x01(\x08\x12\x1e\n\x15\x66reeframe_grid_enable\x18\x81\x01 \x01(\x08\x12\x1f\n\x16\x64\x61rk_eis_enable_global\x18\x85\x01 \x01(\x08\x12\x1f\n\x16metering_enable_global\x18\x86\x01 \x01(\x08\x12\x1f\n\x16\x65nableInternalSplicing\x18\x87\x01 \x01(\x08\x12!\n\x18quick_reader_moving_flag\x18\x93\x01 \x01(\x08\x12:\n\x0fheat_shell_type\x18\x95\x01 \x01(\x0e\x32 .insta360.messages.HeatShellType\x12\x44\n\x14offset_detected_type\x18\x96\x01 \x01(\x0e\x32%.insta360.messages.OffsetDetectedType\x12\x12\n\thas_crash\x18\x9b\x01 \x01(\x08\x1a&\n\x10GyroFilterConfig\x12\x12\n\ndlpf_value\x18\x01 \x01(\r\x1a\xb7\x02\n\x08WifiInfo\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\x05\x12\x36\n\x04mode\x18\x04 \x01(\x0e\x32(.insta360.messages.Options.WifiInfo.Mode\x12\x41\n\nwifi_state\x18\x05 \x01(\x0e\x32-.insta360.messages.Options.WifiInfo.WifiState\x12\x16\n\x0epasswd_version\x18\x06 \x01(\x05\x12\x10\n\x08mac_addr\x18\x07 \x01(\t" \n\x04Mode\x12\x06\n\x02\x41P\x10\x00\x12\x07\n\x03STA\x10\x01\x12\x07\n\x03P2P\x10\x02"3\n\tWifiState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\x06\n\x02ON\x10\x02\x12\x07\n\x03OFF\x10\x03\x1a=\n\x0fWifiChannelList\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12\x14\n\x0c\x63hannel_list\x18\x02 \x01(\x0c\x1a\xa5\x02\n\x08GyroInfo\x12?\n\tgyro_type\x18\x01 \x01(\x0e\x32,.insta360.messages.Options.GyroInfo.GyroType\x12=\n\x08gyro_pos\x18\x02 \x01(\x0e\x32+.insta360.messages.Options.GyroInfo.GyroPos"@\n\x08GyroType\x12\x19\n\x15INSDEV_IMU_TYPE_20948\x10\x00\x12\x19\n\x15INSDEV_IMU_TYPE_40609\x10\x01"W\n\x07GyroPos\x12\x17\n\x13INSDEV_IMU_POS_VIN0\x10\x00\x12\x17\n\x13INSDEV_IMU_POS_VIN1\x10\x01\x12\x1a\n\x16INSDEV_IMU_POS_UNKNOWN\x10\x02"L\n\x11\x41\x63\x63\x46ullScaleRange\x12\x0c\n\x08RANGE_2G\x10\x00\x12\x0c\n\x08RANGE_4G\x10\x01\x12\x0c\n\x08RANGE_8G\x10\x02\x12\r\n\tRANGE_16G\x10\x03"^\n\x12GyroFullScaleRange\x12\x10\n\x0cRANGE_250DPS\x10\x00\x12\x10\n\x0cRANGE_500DPS\x10\x01\x12\x11\n\rRANGE_1000DPS\x10\x02\x12\x11\n\rRANGE_2000DPS\x10\x03"2\n\x0e\x41\x64optionSystem\x12\r\n\tPHONE_IOS\x10\x00\x12\x11\n\rPHONE_ANDROID\x10\x01"\x1e\n\nWifiStatus\x12\x08\n\x04\x41UTO\x10\x00\x12\x06\n\x02ON\x10\x01"F\n\rEvoStatusMode\x12\x17\n\x13UNKNOWN_STATUS_MODE\x10\x00\x12\r\n\tDEGREE180\x10\x01\x12\r\n\tDEGREE360\x10\x02"X\n\x0c\x42TRemoteType\x12\x15\n\x11UNKNOWN_BT_REMOTE\x10\x00\x12\x19\n\x15\x42T_REMOTE_WITHOUT_GPS\x10\x01\x12\x16\n\x12\x42T_REMOTE_WITH_GPS\x10\x02"3\n\x0eQualitySetting\x12\x10\n\x0cHIGH_QUALITY\x10\x00\x12\x0f\n\x0bLOW_QUALITY\x10\x01"%\n\x10TelevisionSystem\x12\x08\n\x04NTSC\x10\x00\x12\x07\n\x03PAL\x10\x01"3\n\x0fVideoEncodeType\x12\x0f\n\x0b\x45NCODE_H264\x10\x00\x12\x0f\n\x0b\x45NCODE_H265\x10\x01"O\n\x10\x45xpectOutputType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0e\n\nINSTA_PANO\x10\x01\x12\x10\n\x0cMULTI_CAMERA\x10\x02\x12\x0c\n\x08ONE_TAKE\x10\x03"B\n\x06HwType\x12\x13\n\x0fHW_TYPE_UNKNOWN\x10\x00\x12\x0f\n\x0bHW_TYPE_MFI\x10\x01\x12\x12\n\x0eHW_TYPE_NO_MFI\x10\x02"\'\n\rLANGUAGE_TYPE\x12\x06\n\x02\x45N\x10\x00\x12\x06\n\x02ZH\x10\x01\x12\x06\n\x02JA\x10\x02"\xbc\x01\n\x11\x43\x61meraPostureType\x12\x1b\n\x17\x43\x41MERA_POSTURE_ROTATE_0\x10\x00\x12\x1c\n\x18\x43\x41MERA_POSTURE_ROTATE_90\x10\x01\x12\x1d\n\x19\x43\x41MERA_POSTURE_ROTATE_180\x10\x02\x12\x1d\n\x19\x43\x41MERA_POSTURE_ROTATE_270\x10\x03\x12\x15\n\x11\x43\x41MERA_POSTURE_UP\x10\x04\x12\x17\n\x13\x43\x41MERA_POSTURE_DOWN\x10\x05"S\n\x0c\x42t_Wakeup_Sw\x12\x14\n\x10\x42t_Wakeup_Sw_Off\x10\x00\x12\x13\n\x0f\x42t_Wakeup_Sw_On\x10\x01\x12\x18\n\x14\x42t_Wakeup_Sw_Unknown\x10\x02*\xbb\x07\n\x0c\x46unctionMode\x12\x18\n\x14\x46UNCTION_MODE_NORMAL\x10\x00\x12\x1d\n\x19\x46UNCTION_MODE_LIVE_STREAM\x10\x01\x12"\n\x1e\x46UNCTION_MODE_MOBILE_TIMELAPSE\x10\x02\x12#\n\x1f\x46UNCTION_MODE_INTERVAL_SHOOTING\x10\x03\x12!\n\x1d\x46UNCTION_MODE_HIGH_FRAME_RATE\x10\x04\x12\x17\n\x13\x46UNCTION_MODE_BURST\x10\x05\x12\x1e\n\x1a\x46UNCTION_MODE_NORMAL_IMAGE\x10\x06\x12\x1e\n\x1a\x46UNCTION_MODE_NORMAL_VIDEO\x10\x07\x12\x1b\n\x17\x46UNCTION_MODE_HDR_IMAGE\x10\x08\x12\x1b\n\x17\x46UNCTION_MODE_HDR_VIDEO\x10\t\x12 \n\x1c\x46UNCTION_MODE_INTERVAL_VIDEO\x10\n\x12"\n\x1e\x46UNCTION_MODE_STATIC_TIMELAPSE\x10\x0b\x12\x1b\n\x17\x46UNCTION_MODE_TIMESHIFT\x10\x0c\x12!\n\x1d\x46UNCTION_MODE_AEB_NIGHT_IMAGE\x10\r\x12)\n%FUNCTION_MODE_NORMAL_POWER_PANO_IMAGE\x10\x0e\x12&\n"FUNCTION_MODE_HDR_POWER_PANO_IMAGE\x10\x0f\x12\x1d\n\x19\x46UNCTION_MODE_SUPER_VIDEO\x10\x10\x12&\n"FUNCTION_MODE_LOOP_RECORDING_VIDEO\x10\x11\x12!\n\x1d\x46UNCTION_MODE_STARLAPSE_IMAGE\x10\x12\x12\x1b\n\x17\x46UNCTION_MODE_FPV_VIDEO\x10\x13\x12\x1d\n\x19\x46UNCTION_MODE_MOVIE_VIDEO\x10\x14\x12"\n\x1e\x46UNCTION_MODE_SLOWMOTION_VIDEO\x10\x15\x12\x1e\n\x1a\x46UNCTION_MODE_SELFIE_VIDEO\x10\x16\x12!\n\x1d\x46UNCTION_MODE_QC_SINGLE_PRESS\x10\x17\x12!\n\x1d\x46UNCTION_MODE_QC_DOUBLE_PRESS\x10\x18\x12%\n!FUNCTION_MODE_CAMERA_SINGLE_PRESS\x10\x19\x12%\n!FUNCTION_MODE_CAMERA_DOUBLE_PRESS\x10\x1a\x12\x1c\n\x18\x46UNCTION_MODE_PURE_VIDEO\x10\x1b*\xce\x02\n\x0b\x43\x61ptureMode\x12\x18\n\x14\x43\x61pture_MODE_UNKNOWN\x10\x00\x12\x17\n\x13\x43\x61pture_MODE_NORMAL\x10\x01\x12\x1b\n\x17\x43\x61pture_MODE_BULLETTIME\x10\x02\x12\x14\n\x10\x43\x61pture_MODE_HDR\x10\x03\x12\x1a\n\x16\x43\x61pture_MODE_TIMESHIFT\x10\x04\x12\x1c\n\x18\x43\x61pture_MODE_SUPER_VIDEO\x10\x05\x12\x1e\n\x1a\x43\x61pture_MODE_LOOPRECORDING\x10\x06\x12\x14\n\x10\x43\x61pture_MODE_FPV\x10\x07\x12\x16\n\x12\x43\x61pture_MODE_MOVIE\x10\x08\x12\x1b\n\x17\x43\x61pture_MODE_SLOWMOTION\x10\t\x12\x17\n\x13\x43\x61pture_MODE_SELFIE\x10\n\x12\x1b\n\x17\x43\x61pture_MODE_PURE_VIDEO\x10\x0b*\xf3\x12\n\nOptionType\x12\x12\n\x0eOPTION_UNKNOWN\x10\x00\x12\x14\n\x10VIDEO_RESOLUTION\x10\x01\x12\x0e\n\nPHOTO_SIZE\x10\x02\x12\x11\n\rVIDEO_BITRATE\x10\x03\x12\x11\n\rAUDIO_BITRATE\x10\x04\x12\x14\n\x10\x41UDIO_SAMPLERATE\x10\x05\x12\x11\n\rORIGIN_OFFSET\x10\x06\x12\x16\n\x12\x43\x41PTURE_TIME_LIMIT\x10\x07\x12\x0f\n\x0bGPS_TIMEOUT\x10\x08\x12\x1a\n\x16REMAINING_CAPTURE_TIME\x10\t\x12\x16\n\x12REMAINING_PICTURES\x10\n\x12\x12\n\x0e\x42\x41TTERY_STATUS\x10\x0b\x12\x0e\n\nLOCAL_TIME\x10\x0c\x12\r\n\tTIME_ZONE\x10\r\x12\x08\n\x04MUTE\x10\x0e\x12\x11\n\rSERIAL_NUMBER\x10\x0f\x12\x08\n\x04UUID\x10\x10\x12\x18\n\x14\x42UTTON_PRESS_OPTIONS\x10\x11\x12\x11\n\rACTIVATE_TIME\x10\x13\x12\x11\n\rSTORAGE_STATE\x10\x14\x12\x0e\n\nLENS_INDEX\x10\x15\x12\x10\n\x0cMEDIA_OFFSET\x10\x16\x12\x0e\n\nSELF_TIMER\x10\x17\x12\x14\n\x10GYRO_SAMPLE_RATE\x10\x18\x12\x18\n\x14\x41\x43\x43_FULL_SCALE_RANGE\x10\x19\x12\x19\n\x15GYRO_FULL_SCALE_RANGE\x10\x1a\x12\x14\n\x10TAKE_RAW_PICTURE\x10\x1b\x12\x0e\n\nGAMMA_MODE\x10\x1c\x12\x0e\n\nMEDIA_TIME\x10\x1d\x12\x14\n\x10\x46IRMWAREREVISION\x10\x1e\x12\x10\n\x0cSYS_ADOPTION\x10\x1f\x12\x0c\n\x08\x43PU_TYPE\x10 \x12\x0f\n\x0bGYRO_FILTER\x10!\x12\x0f\n\x0bMCTF_ENABLE\x10"\x12\x15\n\x11SPORT_MODE_ENABLE\x10#\x12\r\n\tWIFI_INFO\x10$\x12\x15\n\x11WIFI_CHANNEL_LIST\x10%\x12\x14\n\x10\x41UTHORIZATION_ID\x10&\x12\x16\n\x12\x43\x41LIBRATION_OFFSET\x10\'\x12\x12\n\x0ePHOTO_SUB_MODE\x10(\x12\x12\n\x0eVIDEO_SUB_MODE\x10)\x12\x15\n\x11SECOND_STREAM_RES\x10*\x12\x0f\n\x0bWIFI_STATUS\x10+\x12\x13\n\x0f\x45VO_STATUS_MODE\x10,\x12\x14\n\x10ORIGIN_OFFSET_3D\x10-\x12\x13\n\x0fMEDIA_OFFSET_3D\x10.\x12\x19\n\x15\x43\x41LIBRATION_OFFSET_3D\x10/\x12\x0f\n\x0b\x43\x41MERA_TYPE\x10\x30\x12\x15\n\x11\x42T_REMOTE_VERSION\x10\x31\x12\x12\n\x0e\x42T_REMOTE_TYPE\x10\x32\x12\x13\n\x0fQUALITY_SETTING\x10\x33\x12\x17\n\x13OVERHEAT_PROTECTION\x10\x34\x12\x1b\n\x17\x43\x41LIBRATION_ORIENTATION\x10\x35\x12\x14\n\x10STANDBY_DURATION\x10\x36\x12\x18\n\x14QUICK_CAPTURE_ENABLE\x10\x37\x12\x0f\n\x0b\x42T_MAC_ADDR\x10\x38\x12\x15\n\x11TELEVISION_SYSTEM\x10\x39\x12\x18\n\x14SENSOR0_SERIAL_VR360\x10:\x12\x18\n\x14SENSOR1_SERIAL_VR360\x10;\x12\x17\n\x13SENSOR_SERIAL_VR180\x10<\x12\x12\n\x0eMOBVOI_LICENSE\x10=\x12\x15\n\x11MOBVOI_PUBLIC_KEY\x10>\x12\r\n\tGYRO_INFO\x10?\x12\r\n\tSENSOR_ID\x10@\x12\x16\n\x12INTERNAL_FLOWSTATE\x10\x41\x12\x15\n\x11VIDEO_ENCODE_TYPE\x10\x42\x12\x0f\n\x0bSENSOR_INFO\x10\x43\x12\r\n\tIS_SELFIE\x10\x44\x12\x18\n\x14ROLLING_SHUTTER_TIME\x10\x45\x12\x13\n\x0fGYRO_TIME_STAMP\x10\x46\x12\r\n\tVIDEO_FOV\x10G\x12\r\n\tSTILL_FOV\x10H\x12\x16\n\x12GYRO_POLYFIT_STATE\x10I\x12\x18\n\x14GYRO_CALIBRATE_STATE\x10J\x12\x1f\n\x1bMOBVOI_LICENSE_VERITY_STATE\x10K\x12\x12\n\x0e\x46LICKER_GLOBAL\x10L\x12\x0e\n\nTEMP_VALUE\x10M\x12\x14\n\x10ORIGIN_OFFSET_V2\x10N\x12\x14\n\x10ORIGIN_OFFSET_V3\x10O\x12\x13\n\x0fMEDIA_OFFSET_V2\x10P\x12\x13\n\x0fMEDIA_OFFSET_V3\x10Q\x12\x1a\n\x16INSTAPANO_FOCUS_SENSOR\x10R\x12\x16\n\x12\x45XPECT_OUTPUT_TYPE\x10S\x12\x0b\n\x07HW_TYPE\x10T\x12\x1e\n\x1a\x43HARGEBOX_CONNECTED_STATUS\x10U\x12\x10\n\x0c\x42T_CAR_TABLE\x10V\x12\x0c\n\x08PTZ_CTRL\x10W\x12\x13\n\x0f\x43\x41MERA_LANGUAGE\x10X\x12\x12\n\x0eHW_BLE_VERSION\x10Y\x12\x12\n\x0e\x43\x41MERA_POSTURE\x10]\x12\x10\n\x0c\x42T_WAKEUP_SW\x10\x61\x12\x11\n\rOFFSET_STATES\x10g\x12\x13\n\x0fOTA_PKG_VERSION\x10n\x12\x17\n\x13\x42OX_OTA_PKG_VERSION\x10r\x12\x12\n\x0e\x42OX_BT_VERSION\x10s\x12\x0f\n\x0b\x42OX_VERSION\x10t\x12\x0f\n\x0bGO3_VERSION\x10u\x12\x17\n\x13WIFI_WORKING_STATUS\x10v\x12\x18\n\x14\x42UTTON_FOLLOW_OPTION\x10w\x12\x0e\n\nLED_SWITCH\x10x\x12%\n!CAMERA_POSTURE_WHEN_CAPTURE_START\x10z\x12\x31\n-CHARGEBOX_CONNECTED_STATUS_WHEN_CAPTURE_START\x10{\x12\x14\n\x10WINDOW_CROP_INFO\x10|\x12\x13\n\x0e\x41SSISTIVE_GRID\x10\x80\x01\x12\x13\n\x0e\x46REEFRAME_GRID\x10\x81\x01\x12\x1b\n\x16\x44\x41RK_EIS_ENABLE_GLOBAL\x10\x85\x01\x12\x1b\n\x16METERING_ENABLE_GLOBAL\x10\x86\x01\x12\x16\n\x11INTERNAL_SPLICING\x10\x87\x01\x12\x1d\n\x18QUICK_READER_MOVING_FLAG\x10\x93\x01\x12\x14\n\x0fHEAT_SHELL_TYPE\x10\x95\x01\x12\x19\n\x14OFFSET_DETECTED_TYPE\x10\x96\x01\x12\x0e\n\tHAS_CRASH\x10\x9b\x01\x12\x10\n\x0bOPTIONS_NUM\x10\x9c\x01\x42\x08\xa2\x02\x05INSPBP\x00P\x01P\x02P\x03P\x04P\x05P\x06P\x07P\x08P\tP\nb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "options_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_FUNCTIONMODE"]._serialized_start = 6257
    _globals["_FUNCTIONMODE"]._serialized_end = 7212
    _globals["_CAPTUREMODE"]._serialized_start = 7215
    _globals["_CAPTUREMODE"]._serialized_end = 7549
    _globals["_OPTIONTYPE"]._serialized_start = 7552
    _globals["_OPTIONTYPE"]._serialized_end = 9971
    _globals["_OPTIONS"]._serialized_start = 221
    _globals["_OPTIONS"]._serialized_end = 6254
    _globals["_OPTIONS_GYROFILTERCONFIG"]._serialized_start = 4512
    _globals["_OPTIONS_GYROFILTERCONFIG"]._serialized_end = 4550
    _globals["_OPTIONS_WIFIINFO"]._serialized_start = 4553
    _globals["_OPTIONS_WIFIINFO"]._serialized_end = 4864
    _globals["_OPTIONS_WIFIINFO_MODE"]._serialized_start = 4779
    _globals["_OPTIONS_WIFIINFO_MODE"]._serialized_end = 4811
    _globals["_OPTIONS_WIFIINFO_WIFISTATE"]._serialized_start = 4813
    _globals["_OPTIONS_WIFIINFO_WIFISTATE"]._serialized_end = 4864
    _globals["_OPTIONS_WIFICHANNELLIST"]._serialized_start = 4866
    _globals["_OPTIONS_WIFICHANNELLIST"]._serialized_end = 4927
    _globals["_OPTIONS_GYROINFO"]._serialized_start = 4930
    _globals["_OPTIONS_GYROINFO"]._serialized_end = 5223
    _globals["_OPTIONS_GYROINFO_GYROTYPE"]._serialized_start = 5070
    _globals["_OPTIONS_GYROINFO_GYROTYPE"]._serialized_end = 5134
    _globals["_OPTIONS_GYROINFO_GYROPOS"]._serialized_start = 5136
    _globals["_OPTIONS_GYROINFO_GYROPOS"]._serialized_end = 5223
    _globals["_OPTIONS_ACCFULLSCALERANGE"]._serialized_start = 5225
    _globals["_OPTIONS_ACCFULLSCALERANGE"]._serialized_end = 5301
    _globals["_OPTIONS_GYROFULLSCALERANGE"]._serialized_start = 5303
    _globals["_OPTIONS_GYROFULLSCALERANGE"]._serialized_end = 5397
    _globals["_OPTIONS_ADOPTIONSYSTEM"]._serialized_start = 5399
    _globals["_OPTIONS_ADOPTIONSYSTEM"]._serialized_end = 5449
    _globals["_OPTIONS_WIFISTATUS"]._serialized_start = 5451
    _globals["_OPTIONS_WIFISTATUS"]._serialized_end = 5481
    _globals["_OPTIONS_EVOSTATUSMODE"]._serialized_start = 5483
    _globals["_OPTIONS_EVOSTATUSMODE"]._serialized_end = 5553
    _globals["_OPTIONS_BTREMOTETYPE"]._serialized_start = 5555
    _globals["_OPTIONS_BTREMOTETYPE"]._serialized_end = 5643
    _globals["_OPTIONS_QUALITYSETTING"]._serialized_start = 5645
    _globals["_OPTIONS_QUALITYSETTING"]._serialized_end = 5696
    _globals["_OPTIONS_TELEVISIONSYSTEM"]._serialized_start = 5698
    _globals["_OPTIONS_TELEVISIONSYSTEM"]._serialized_end = 5735
    _globals["_OPTIONS_VIDEOENCODETYPE"]._serialized_start = 5737
    _globals["_OPTIONS_VIDEOENCODETYPE"]._serialized_end = 5788
    _globals["_OPTIONS_EXPECTOUTPUTTYPE"]._serialized_start = 5790
    _globals["_OPTIONS_EXPECTOUTPUTTYPE"]._serialized_end = 5869
    _globals["_OPTIONS_HWTYPE"]._serialized_start = 5871
    _globals["_OPTIONS_HWTYPE"]._serialized_end = 5937
    _globals["_OPTIONS_LANGUAGE_TYPE"]._serialized_start = 5939
    _globals["_OPTIONS_LANGUAGE_TYPE"]._serialized_end = 5978
    _globals["_OPTIONS_CAMERAPOSTURETYPE"]._serialized_start = 5981
    _globals["_OPTIONS_CAMERAPOSTURETYPE"]._serialized_end = 6169
    _globals["_OPTIONS_BT_WAKEUP_SW"]._serialized_start = 6171
    _globals["_OPTIONS_BT_WAKEUP_SW"]._serialized_end = 6254
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: battery.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\rbattery.proto\x12\x11insta360.messages"\xa4\x02\n\rBatteryStatus\x12>\n\npower_type\x18\x01 \x01(\x0e\x32*.insta360.messages.BatteryStatus.PowerType\x12\x15\n\rbattery_level\x18\x02 \x01(\r\x12\x15\n\rbattery_scale\x18\x03 \x01(\r\x12\x42\n\x0c\x62\x61ttery_type\x18\x04 \x01(\x0e\x32,.insta360.messages.BatteryStatus.BatteryType"%\n\tPowerType\x12\x0b\n\x07\x42\x41TTERY\x10\x00\x12\x0b\n\x07\x41\x44\x41PTER\x10\x01":\n\x0b\x42\x61tteryType\x12\t\n\x05THICK\x10\x00\x12\x08\n\x04THIN\x10\x01\x12\x0c\n\x08VERTICAL\x10\x02\x12\x08\n\x04NONE\x10\x64\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "battery_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_BATTERYSTATUS"]._serialized_start = 37
    _globals["_BATTERYSTATUS"]._serialized_end = 329
    _globals["_BATTERYSTATUS_POWERTYPE"]._serialized_start = 232
    _globals["_BATTERYSTATUS_POWERTYPE"]._serialized_end = 269
    _globals["_BATTERYSTATUS_BATTERYTYPE"]._serialized_start = 271
    _globals["_BATTERYSTATUS_BATTERYTYPE"]._serialized_end = 329
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: timelapse.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0ftimelapse.proto\x12\x11insta360.messages"\xcf\x01\n\x10TimelapseOptions\x12\x10\n\x08\x64uration\x18\x01 \x01(\r\x12\x11\n\tlapseTime\x18\x02 \x01(\r\x12\x43\n\x0boutput_type\x18\x03 \x01(\x0e\x32..insta360.messages.TimelapseOptions.OutputType\x12\x1b\n\x13\x61\x63\x63\x65lerate_fequency\x18\x04 \x01(\r"4\n\nOutputType\x12\x0f\n\x0b\x44oNotChange\x10\x00\x12\t\n\x05Video\x10\x01\x12\n\n\x06Images\x10\x02*\xc1\x02\n\rTimelapseMode\x12\x13\n\x0fTIMELAPSE_MIXED\x10\x00\x12\x1a\n\x16MOBILE_TIMELAPSE_VIDEO\x10\x01\x12\x1f\n\x1bTIMELAPSE_INTERVAL_SHOOTING\x10\x02\x12\x1a\n\x16STATIC_TIMELAPSE_VIDEO\x10\x03\x12\x1c\n\x18TIMELAPSE_INTERVAL_VIDEO\x10\x04\x12 \n\x1cTIMELAPSE_STARLAPSE_SHOOTING\x10\x05\x12\x1d\n\x19TIMELAPSE_QC_SINGLE_PRESS\x10\x06\x12\x1d\n\x19TIMELAPSE_QC_DOUBLE_PRESS\x10\x07\x12!\n\x1dTIMELAPSE_CAMERA_SINGLE_PRESS\x10\x08\x12!\n\x1dTIMELAPSE_CAMERA_DOUBLE_PRESS\x10\tB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "timelapse_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_TIMELAPSEMODE"]._serialized_start = 249
    _globals["_TIMELAPSEMODE"]._serialized_end = 570
    _globals["_TIMELAPSEOPTIONS"]._serialized_start = 39
    _globals["_TIMELAPSEOPTIONS"]._serialized_end = 246
    _globals["_TIMELAPSEOPTIONS_OUTPUTTYPE"]._serialized_start = 194
    _globals["_TIMELAPSEOPTIONS_OUTPUTTYPE"]._serialized_end = 246
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_key_time_point.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from options_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18set_key_time_point.proto\x12\x11insta360.messages\x1a\roptions.proto"\xb0\x01\n\x0fSetKeyTimePoint\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x41\n\x04type\x18\x02 \x01(\x0e\x32\x33.insta360.messages.SetKeyTimePoint.KeyTimePointType\x12\x12\n\ntypeDetail\x18\x03 \x01(\t"3\n\x10KeyTimePointType\x12\x0b\n\x07INSTANT\x10\x00\x12\t\n\x05START\x10\x01\x12\x07\n\x03\x45ND\x10\x02"\x15\n\x13SetKeyTimePointRespB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_key_time_point_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETKEYTIMEPOINT"]._serialized_start = 63
    _globals["_SETKEYTIMEPOINT"]._serialized_end = 239
    _globals["_SETKEYTIMEPOINT_KEYTIMEPOINTTYPE"]._serialized_start = 188
    _globals["_SETKEYTIMEPOINT_KEYTIMEPOINTTYPE"]._serialized_end = 239
    _globals["_SETKEYTIMEPOINTRESP"]._serialized_start = 241
    _globals["_SETKEYTIMEPOINTRESP"]._serialized_end = 262
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: storage.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\rstorage.proto\x12\x11insta360.messages"\x9c\x01\n\x0cStorageState\x12\x30\n\ncard_state\x18\x01 \x01(\x0e\x32\x1c.insta360.messages.CardState\x12\x12\n\nfree_space\x18\x02 \x01(\x04\x12\x13\n\x0btotal_space\x18\x03 \x01(\x04\x12\x31\n\x08location\x18\x04 \x01(\x0e\x32\x1f.insta360.messages.CardLocation*\x8f\x01\n\tCardState\x12\x10\n\x0cSTOR_CS_PASS\x10\x00\x12\x12\n\x0eSTOR_CS_NOCARD\x10\x01\x12\x13\n\x0fSTOR_CS_NOSPACE\x10\x02\x12\x1a\n\x16STOR_CS_INVALID_FORMAT\x10\x03\x12\x12\n\x0eSTOR_CS_WPCARD\x10\x04\x12\x17\n\x13STOR_CS_OTHER_ERROR\x10\x05*6\n\x0c\x43\x61rdLocation\x12\x12\n\x0eSTOR_CL_CAMERA\x10\x00\x12\x12\n\x0eSTOR_CL_READER\x10\x01\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "storage_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CARDSTATE"]._serialized_start = 196
    _globals["_CARDSTATE"]._serialized_end = 339
    _globals["_CARDLOCATION"]._serialized_start = 341
    _globals["_CARDLOCATION"]._serialized_end = 395
    _globals["_STORAGESTATE"]._serialized_start = 37
    _globals["_STORAGESTATE"]._serialized_end = 193
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: download_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x64ownload_info.proto\x12\x11insta360.messages"\xe9\x01\n\x0c\x44ownLoadInfo\x12\x10\n\x08totalNum\x18\x01 \x01(\x04\x12\x12\n\ncurrentNum\x18\x02 \x01(\x04\x12\x12\n\npercentage\x18\x03 \x01(\x01\x12\x36\n\x06status\x18\x04 \x01(\x0e\x32&.insta360.messages.DownLoadInfo.Status\x12\x12\n\nsuccessNum\x18\x05 \x01(\x04"S\n\x06Status\x12\n\n\x06UNKNOW\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x08\n\x04\x46\x41IL\x10\x02\x12\t\n\x05PAUSE\x10\x03\x12\x0f\n\x0b\x44OWNLOADING\x10\x04\x12\n\n\x06\x43\x41NCEL\x10\x05"\xbc\x03\n\x16\x44ownloadListResultSync\x12P\n\x0f\x61\x64\x64_list_result\x18\x01 \x01(\x0e\x32\x37.insta360.messages.DownloadListResultSync.AddListResult\x12\x46\n\x05\x65rror\x18\x02 \x01(\x0e\x32\x37.insta360.messages.DownloadListResultSync.DownloadError\x12\x15\n\ris_clear_list\x18\x03 \x01(\x08\x12\x18\n\x10success_file_num\x18\x04 \x01(\x04\x12\x16\n\x0e\x65rror_file_num\x18\x05 \x01(\x04"M\n\rAddListResult\x12\n\n\x06UNKNOW\x10\x00\x12\x0f\n\x0b\x41LL_SUCCESS\x10\x01\x12\x08\n\x04\x46\x41IL\x10\x02\x12\x15\n\x11PARTIALLY_SUCCESS\x10\x03"p\n\rDownloadError\x12\x0c\n\x08\x45RR_NONE\x10\x00\x12\x0e\n\nERR_UNKNOW\x10\x01\x12\x10\n\x0c\x45RR_NO_SPACE\x10\x02\x12\x18\n\x14\x45RR_NOT_SUPPORT_FILE\x10\x03\x12\x15\n\x11\x45RR_NO_PERMISSION\x10\x04\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "download_info_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_DOWNLOADINFO"]._serialized_start = 43
    _globals["_DOWNLOADINFO"]._serialized_end = 276
    _globals["_DOWNLOADINFO_STATUS"]._serialized_start = 193
    _globals["_DOWNLOADINFO_STATUS"]._serialized_end = 276
    _globals["_DOWNLOADLISTRESULTSYNC"]._serialized_start = 279
    _globals["_DOWNLOADLISTRESULTSYNC"]._serialized_end = 723
    _globals["_DOWNLOADLISTRESULTSYNC_ADDLISTRESULT"]._serialized_start = 532
    _globals["_DOWNLOADLISTRESULTSYNC_ADDLISTRESULT"]._serialized_end = 609
    _globals["_DOWNLOADLISTRESULTSYNC_DOWNLOADERROR"]._serialized_start = 611
    _globals["_DOWNLOADLISTRESULTSYNC_DOWNLOADERROR"]._serialized_end = 723
# @@protoc_insertion_point(module_scope)
